import{r as d,g as Qo,o as Ct,f as Wn,m as Vn,s as Qt,b as yi,c as bi,a as xi,l as fe,d as wi,e as fn,h as Cr,t as pn,i as Er,j as vi,k as ki,n as Zo,p as el,q as Ci,u as An,v as Ei,w as Si,x as Ri,y as Pi,z as Oi,A as Ti,B as hn,C as Ii,D as Di,E as Li,S as Ai,F as $i,G as gn,H as _i,I as ji,J as ut,K as tl,L as Fi,M as H,N as U,R as V,O as Mi}from"./@app-libs-DFb4Vfds.js";var mn={exports:{}},yt={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Sr;function Ni(){if(Sr)return yt;Sr=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,o,l){var i=null;if(l!==void 0&&(i=""+l),o.key!==void 0&&(i=""+o.key),"key"in o){l={};for(var a in o)a!=="key"&&(l[a]=o[a])}else l=o;return o=l.ref,{$$typeof:e,type:r,key:i,ref:o!==void 0?o:null,props:l}}return yt.Fragment=t,yt.jsx=n,yt.jsxs=n,yt}var Rr;function Hi(){return Rr||(Rr=1,mn.exports=Ni()),mn.exports}var yn=Hi(),bt={},Pr;function zi(){if(Pr)return bt;Pr=1,Object.defineProperty(bt,"__esModule",{value:!0}),bt.parse=i,bt.serialize=c;const e=/^[\u0021-\u003A\u003C\u003E-\u007E]+$/,t=/^[\u0021-\u003A\u003C-\u007E]*$/,n=/^([.]?[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)([.][a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)*$/i,r=/^[\u0020-\u003A\u003D-\u007E]*$/,o=Object.prototype.toString,l=(()=>{const p=function(){};return p.prototype=Object.create(null),p})();function i(p,h){const g=new l,m=p.length;if(m<2)return g;const w=(h==null?void 0:h.decode)||u;let y=0;do{const v=p.indexOf("=",y);if(v===-1)break;const x=p.indexOf(";",y),S=x===-1?m:x;if(v>S){y=p.lastIndexOf(";",v-1)+1;continue}const I=a(p,y,v),F=s(p,v,I),T=p.slice(I,F);if(g[T]===void 0){let $=a(p,v+1,S),M=s(p,S,$);const _=w(p.slice($,M));g[T]=_}y=S+1}while(y<m);return g}function a(p,h,g){do{const m=p.charCodeAt(h);if(m!==32&&m!==9)return h}while(++h<g);return g}function s(p,h,g){for(;h>g;){const m=p.charCodeAt(--h);if(m!==32&&m!==9)return h+1}return g}function c(p,h,g){const m=(g==null?void 0:g.encode)||encodeURIComponent;if(!e.test(p))throw new TypeError(`argument name is invalid: ${p}`);const w=m(h);if(!t.test(w))throw new TypeError(`argument val is invalid: ${h}`);let y=p+"="+w;if(!g)return y;if(g.maxAge!==void 0){if(!Number.isInteger(g.maxAge))throw new TypeError(`option maxAge is invalid: ${g.maxAge}`);y+="; Max-Age="+g.maxAge}if(g.domain){if(!n.test(g.domain))throw new TypeError(`option domain is invalid: ${g.domain}`);y+="; Domain="+g.domain}if(g.path){if(!r.test(g.path))throw new TypeError(`option path is invalid: ${g.path}`);y+="; Path="+g.path}if(g.expires){if(!f(g.expires)||!Number.isFinite(g.expires.valueOf()))throw new TypeError(`option expires is invalid: ${g.expires}`);y+="; Expires="+g.expires.toUTCString()}if(g.httpOnly&&(y+="; HttpOnly"),g.secure&&(y+="; Secure"),g.partitioned&&(y+="; Partitioned"),g.priority)switch(typeof g.priority=="string"?g.priority.toLowerCase():void 0){case"low":y+="; Priority=Low";break;case"medium":y+="; Priority=Medium";break;case"high":y+="; Priority=High";break;default:throw new TypeError(`option priority is invalid: ${g.priority}`)}if(g.sameSite)switch(typeof g.sameSite=="string"?g.sameSite.toLowerCase():g.sameSite){case!0:case"strict":y+="; SameSite=Strict";break;case"lax":y+="; SameSite=Lax";break;case"none":y+="; SameSite=None";break;default:throw new TypeError(`option sameSite is invalid: ${g.sameSite}`)}return y}function u(p){if(p.indexOf("%")===-1)return p;try{return decodeURIComponent(p)}catch{return p}}function f(p){return o.call(p)==="[object Date]"}return bt}zi();/**
 * react-router v7.4.1
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var Or="popstate";function Bi(e={}){function t(r,o){let{pathname:l,search:i,hash:a}=r.location;return $n("",{pathname:l,search:i,hash:a},o.state&&o.state.usr||null,o.state&&o.state.key||"default")}function n(r,o){return typeof o=="string"?o:Ot(o)}return Wi(t,n,null,e)}function K(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function Pe(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function Ui(){return Math.random().toString(36).substring(2,10)}function Tr(e,t){return{usr:e.state,key:e.key,idx:t}}function $n(e,t,n=null,r){return{pathname:typeof e=="string"?e:e.pathname,search:"",hash:"",...typeof t=="string"?dt(t):t,state:n,key:t&&t.key||r||Ui()}}function Ot({pathname:e="/",search:t="",hash:n=""}){return t&&t!=="?"&&(e+=t.charAt(0)==="?"?t:"?"+t),n&&n!=="#"&&(e+=n.charAt(0)==="#"?n:"#"+n),e}function dt(e){let t={};if(e){let n=e.indexOf("#");n>=0&&(t.hash=e.substring(n),e=e.substring(0,n));let r=e.indexOf("?");r>=0&&(t.search=e.substring(r),e=e.substring(0,r)),e&&(t.pathname=e)}return t}function Wi(e,t,n,r={}){let{window:o=document.defaultView,v5Compat:l=!1}=r,i=o.history,a="POP",s=null,c=u();c==null&&(c=0,i.replaceState({...i.state,idx:c},""));function u(){return(i.state||{idx:null}).idx}function f(){a="POP";let w=u(),y=w==null?null:w-c;c=w,s&&s({action:a,location:m.location,delta:y})}function p(w,y){a="PUSH";let v=$n(m.location,w,y);c=u()+1;let x=Tr(v,c),S=m.createHref(v);try{i.pushState(x,"",S)}catch(I){if(I instanceof DOMException&&I.name==="DataCloneError")throw I;o.location.assign(S)}l&&s&&s({action:a,location:m.location,delta:1})}function h(w,y){a="REPLACE";let v=$n(m.location,w,y);c=u();let x=Tr(v,c),S=m.createHref(v);i.replaceState(x,"",S),l&&s&&s({action:a,location:m.location,delta:0})}function g(w){let y=o.location.origin!=="null"?o.location.origin:o.location.href,v=typeof w=="string"?w:Ot(w);return v=v.replace(/ $/,"%20"),K(y,`No window.location.(origin|href) available to create URL for href: ${v}`),new URL(v,y)}let m={get action(){return a},get location(){return e(o,i)},listen(w){if(s)throw new Error("A history only accepts one active listener");return o.addEventListener(Or,f),s=w,()=>{o.removeEventListener(Or,f),s=null}},createHref(w){return t(o,w)},createURL:g,encodeLocation(w){let y=g(w);return{pathname:y.pathname,search:y.search,hash:y.hash}},push:p,replace:h,go(w){return i.go(w)}};return m}function nl(e,t,n="/"){return Vi(e,t,n,!1)}function Vi(e,t,n,r){let o=typeof t=="string"?dt(t):t,l=_e(o.pathname||"/",n);if(l==null)return null;let i=rl(e);qi(i);let a=null;for(let s=0;a==null&&s<i.length;++s){let c=ra(l);a=ta(i[s],c,r)}return a}function rl(e,t=[],n=[],r=""){let o=(l,i,a)=>{let s={relativePath:a===void 0?l.path||"":a,caseSensitive:l.caseSensitive===!0,childrenIndex:i,route:l};s.relativePath.startsWith("/")&&(K(s.relativePath.startsWith(r),`Absolute route path "${s.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),s.relativePath=s.relativePath.slice(r.length));let c=$e([r,s.relativePath]),u=n.concat(s);l.children&&l.children.length>0&&(K(l.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${c}".`),rl(l.children,t,u,c)),!(l.path==null&&!l.index)&&t.push({path:c,score:Zi(c,l.index),routesMeta:u})};return e.forEach((l,i)=>{var a;if(l.path===""||!((a=l.path)!=null&&a.includes("?")))o(l,i);else for(let s of ol(l.path))o(l,i,s)}),t}function ol(e){let t=e.split("/");if(t.length===0)return[];let[n,...r]=t,o=n.endsWith("?"),l=n.replace(/\?$/,"");if(r.length===0)return o?[l,""]:[l];let i=ol(r.join("/")),a=[];return a.push(...i.map(s=>s===""?l:[l,s].join("/"))),o&&a.push(...i),a.map(s=>e.startsWith("/")&&s===""?"/":s)}function qi(e){e.sort((t,n)=>t.score!==n.score?n.score-t.score:ea(t.routesMeta.map(r=>r.childrenIndex),n.routesMeta.map(r=>r.childrenIndex)))}var Gi=/^:[\w-]+$/,Xi=3,Yi=2,Ji=1,Ki=10,Qi=-2,Ir=e=>e==="*";function Zi(e,t){let n=e.split("/"),r=n.length;return n.some(Ir)&&(r+=Qi),t&&(r+=Yi),n.filter(o=>!Ir(o)).reduce((o,l)=>o+(Gi.test(l)?Xi:l===""?Ji:Ki),r)}function ea(e,t){return e.length===t.length&&e.slice(0,-1).every((r,o)=>r===t[o])?e[e.length-1]-t[t.length-1]:0}function ta(e,t,n=!1){let{routesMeta:r}=e,o={},l="/",i=[];for(let a=0;a<r.length;++a){let s=r[a],c=a===r.length-1,u=l==="/"?t:t.slice(l.length)||"/",f=Zt({path:s.relativePath,caseSensitive:s.caseSensitive,end:c},u),p=s.route;if(!f&&c&&n&&!r[r.length-1].route.index&&(f=Zt({path:s.relativePath,caseSensitive:s.caseSensitive,end:!1},u)),!f)return null;Object.assign(o,f.params),i.push({params:o,pathname:$e([l,f.pathname]),pathnameBase:aa($e([l,f.pathnameBase])),route:p}),f.pathnameBase!=="/"&&(l=$e([l,f.pathnameBase]))}return i}function Zt(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[n,r]=na(e.path,e.caseSensitive,e.end),o=t.match(n);if(!o)return null;let l=o[0],i=l.replace(/(.)\/+$/,"$1"),a=o.slice(1);return{params:r.reduce((c,{paramName:u,isOptional:f},p)=>{if(u==="*"){let g=a[p]||"";i=l.slice(0,l.length-g.length).replace(/(.)\/+$/,"$1")}const h=a[p];return f&&!h?c[u]=void 0:c[u]=(h||"").replace(/%2F/g,"/"),c},{}),pathname:l,pathnameBase:i,pattern:e}}function na(e,t=!1,n=!0){Pe(e==="*"||!e.endsWith("*")||e.endsWith("/*"),`Route path "${e}" will be treated as if it were "${e.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${e.replace(/\*$/,"/*")}".`);let r=[],o="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(i,a,s)=>(r.push({paramName:a,isOptional:s!=null}),s?"/?([^\\/]+)?":"/([^\\/]+)"));return e.endsWith("*")?(r.push({paramName:"*"}),o+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):n?o+="\\/*$":e!==""&&e!=="/"&&(o+="(?:(?=\\/|$))"),[new RegExp(o,t?void 0:"i"),r]}function ra(e){try{return e.split("/").map(t=>decodeURIComponent(t).replace(/\//g,"%2F")).join("/")}catch(t){return Pe(!1,`The URL path "${e}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${t}).`),e}}function _e(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let n=t.endsWith("/")?t.length-1:t.length,r=e.charAt(n);return r&&r!=="/"?null:e.slice(n)||"/"}function oa(e,t="/"){let{pathname:n,search:r="",hash:o=""}=typeof e=="string"?dt(e):e;return{pathname:n?n.startsWith("/")?n:la(n,t):t,search:sa(r),hash:ca(o)}}function la(e,t){let n=t.replace(/\/+$/,"").split("/");return e.split("/").forEach(o=>{o===".."?n.length>1&&n.pop():o!=="."&&n.push(o)}),n.length>1?n.join("/"):"/"}function bn(e,t,n,r){return`Cannot include a '${e}' character in a manually specified \`to.${t}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${n}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function ia(e){return e.filter((t,n)=>n===0||t.route.path&&t.route.path.length>0)}function ll(e){let t=ia(e);return t.map((n,r)=>r===t.length-1?n.pathname:n.pathnameBase)}function il(e,t,n,r=!1){let o;typeof e=="string"?o=dt(e):(o={...e},K(!o.pathname||!o.pathname.includes("?"),bn("?","pathname","search",o)),K(!o.pathname||!o.pathname.includes("#"),bn("#","pathname","hash",o)),K(!o.search||!o.search.includes("#"),bn("#","search","hash",o)));let l=e===""||o.pathname==="",i=l?"/":o.pathname,a;if(i==null)a=n;else{let f=t.length-1;if(!r&&i.startsWith("..")){let p=i.split("/");for(;p[0]==="..";)p.shift(),f-=1;o.pathname=p.join("/")}a=f>=0?t[f]:"/"}let s=oa(o,a),c=i&&i!=="/"&&i.endsWith("/"),u=(l||i===".")&&n.endsWith("/");return!s.pathname.endsWith("/")&&(c||u)&&(s.pathname+="/"),s}var $e=e=>e.join("/").replace(/\/\/+/g,"/"),aa=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/"),sa=e=>!e||e==="?"?"":e.startsWith("?")?e:"?"+e,ca=e=>!e||e==="#"?"":e.startsWith("#")?e:"#"+e;function ua(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}var al=["POST","PUT","PATCH","DELETE"];new Set(al);var da=["GET",...al];new Set(da);var ft=d.createContext(null);ft.displayName="DataRouter";var on=d.createContext(null);on.displayName="DataRouterState";var sl=d.createContext({isTransitioning:!1});sl.displayName="ViewTransition";var fa=d.createContext(new Map);fa.displayName="Fetchers";var pa=d.createContext(null);pa.displayName="Await";var Oe=d.createContext(null);Oe.displayName="Navigation";var Dt=d.createContext(null);Dt.displayName="Location";var Te=d.createContext({outlet:null,matches:[],isDataRoute:!1});Te.displayName="Route";var qn=d.createContext(null);qn.displayName="RouteError";function ha(e,{relative:t}={}){K(Lt(),"useHref() may be used only in the context of a <Router> component.");let{basename:n,navigator:r}=d.useContext(Oe),{hash:o,pathname:l,search:i}=At(e,{relative:t}),a=l;return n!=="/"&&(a=l==="/"?n:$e([n,l])),r.createHref({pathname:a,search:i,hash:o})}function Lt(){return d.useContext(Dt)!=null}function Ye(){return K(Lt(),"useLocation() may be used only in the context of a <Router> component."),d.useContext(Dt).location}var cl="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function ul(e){d.useContext(Oe).static||d.useLayoutEffect(e)}function ga(){let{isDataRoute:e}=d.useContext(Te);return e?Oa():ma()}function ma(){K(Lt(),"useNavigate() may be used only in the context of a <Router> component.");let e=d.useContext(ft),{basename:t,navigator:n}=d.useContext(Oe),{matches:r}=d.useContext(Te),{pathname:o}=Ye(),l=JSON.stringify(ll(r)),i=d.useRef(!1);return ul(()=>{i.current=!0}),d.useCallback((s,c={})=>{if(Pe(i.current,cl),!i.current)return;if(typeof s=="number"){n.go(s);return}let u=il(s,JSON.parse(l),o,c.relative==="path");e==null&&t!=="/"&&(u.pathname=u.pathname==="/"?t:$e([t,u.pathname])),(c.replace?n.replace:n.push)(u,c.state,c)},[t,n,l,o,e])}d.createContext(null);function hf(){let{matches:e}=d.useContext(Te),t=e[e.length-1];return t?t.params:{}}function At(e,{relative:t}={}){let{matches:n}=d.useContext(Te),{pathname:r}=Ye(),o=JSON.stringify(ll(n));return d.useMemo(()=>il(e,JSON.parse(o),r,t==="path"),[e,o,r,t])}function ya(e,t){return dl(e,t)}function dl(e,t,n,r){var v;K(Lt(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:o,static:l}=d.useContext(Oe),{matches:i}=d.useContext(Te),a=i[i.length-1],s=a?a.params:{},c=a?a.pathname:"/",u=a?a.pathnameBase:"/",f=a&&a.route;{let x=f&&f.path||"";fl(c,!f||x.endsWith("*")||x.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${c}" (under <Route path="${x}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${x}"> to <Route path="${x==="/"?"*":`${x}/*`}">.`)}let p=Ye(),h;if(t){let x=typeof t=="string"?dt(t):t;K(u==="/"||((v=x.pathname)==null?void 0:v.startsWith(u)),`When overriding the location using \`<Routes location>\` or \`useRoutes(routes, location)\`, the location pathname must begin with the portion of the URL pathname that was matched by all parent routes. The current pathname base is "${u}" but pathname "${x.pathname}" was given in the \`location\` prop.`),h=x}else h=p;let g=h.pathname||"/",m=g;if(u!=="/"){let x=u.replace(/^\//,"").split("/");m="/"+g.replace(/^\//,"").split("/").slice(x.length).join("/")}let w=!l&&n&&n.matches&&n.matches.length>0?n.matches:nl(e,{pathname:m});Pe(f||w!=null,`No routes matched location "${h.pathname}${h.search}${h.hash}" `),Pe(w==null||w[w.length-1].route.element!==void 0||w[w.length-1].route.Component!==void 0||w[w.length-1].route.lazy!==void 0,`Matched leaf route at location "${h.pathname}${h.search}${h.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`);let y=ka(w&&w.map(x=>Object.assign({},x,{params:Object.assign({},s,x.params),pathname:$e([u,o.encodeLocation?o.encodeLocation(x.pathname).pathname:x.pathname]),pathnameBase:x.pathnameBase==="/"?u:$e([u,o.encodeLocation?o.encodeLocation(x.pathnameBase).pathname:x.pathnameBase])})),i,n,r);return t&&y?d.createElement(Dt.Provider,{value:{location:{pathname:"/",search:"",hash:"",state:null,key:"default",...h},navigationType:"POP"}},y):y}function ba(){let e=Pa(),t=ua(e)?`${e.status} ${e.statusText}`:e instanceof Error?e.message:JSON.stringify(e),n=e instanceof Error?e.stack:null,r="rgba(200,200,200, 0.5)",o={padding:"0.5rem",backgroundColor:r},l={padding:"2px 4px",backgroundColor:r},i=null;return console.error("Error handled by React Router default ErrorBoundary:",e),i=d.createElement(d.Fragment,null,d.createElement("p",null,"💿 Hey developer 👋"),d.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",d.createElement("code",{style:l},"ErrorBoundary")," or"," ",d.createElement("code",{style:l},"errorElement")," prop on your route.")),d.createElement(d.Fragment,null,d.createElement("h2",null,"Unexpected Application Error!"),d.createElement("h3",{style:{fontStyle:"italic"}},t),n?d.createElement("pre",{style:o},n):null,i)}var xa=d.createElement(ba,null),wa=class extends d.Component{constructor(e){super(e),this.state={location:e.location,revalidation:e.revalidation,error:e.error}}static getDerivedStateFromError(e){return{error:e}}static getDerivedStateFromProps(e,t){return t.location!==e.location||t.revalidation!=="idle"&&e.revalidation==="idle"?{error:e.error,location:e.location,revalidation:e.revalidation}:{error:e.error!==void 0?e.error:t.error,location:t.location,revalidation:e.revalidation||t.revalidation}}componentDidCatch(e,t){console.error("React Router caught the following error during render",e,t)}render(){return this.state.error!==void 0?d.createElement(Te.Provider,{value:this.props.routeContext},d.createElement(qn.Provider,{value:this.state.error,children:this.props.component})):this.props.children}};function va({routeContext:e,match:t,children:n}){let r=d.useContext(ft);return r&&r.static&&r.staticContext&&(t.route.errorElement||t.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=t.route.id),d.createElement(Te.Provider,{value:e},n)}function ka(e,t=[],n=null,r=null){if(e==null){if(!n)return null;if(n.errors)e=n.matches;else if(t.length===0&&!n.initialized&&n.matches.length>0)e=n.matches;else return null}let o=e,l=n==null?void 0:n.errors;if(l!=null){let s=o.findIndex(c=>c.route.id&&(l==null?void 0:l[c.route.id])!==void 0);K(s>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(l).join(",")}`),o=o.slice(0,Math.min(o.length,s+1))}let i=!1,a=-1;if(n)for(let s=0;s<o.length;s++){let c=o[s];if((c.route.HydrateFallback||c.route.hydrateFallbackElement)&&(a=s),c.route.id){let{loaderData:u,errors:f}=n,p=c.route.loader&&!u.hasOwnProperty(c.route.id)&&(!f||f[c.route.id]===void 0);if(c.route.lazy||p){i=!0,a>=0?o=o.slice(0,a+1):o=[o[0]];break}}}return o.reduceRight((s,c,u)=>{let f,p=!1,h=null,g=null;n&&(f=l&&c.route.id?l[c.route.id]:void 0,h=c.route.errorElement||xa,i&&(a<0&&u===0?(fl("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),p=!0,g=null):a===u&&(p=!0,g=c.route.hydrateFallbackElement||null)));let m=t.concat(o.slice(0,u+1)),w=()=>{let y;return f?y=h:p?y=g:c.route.Component?y=d.createElement(c.route.Component,null):c.route.element?y=c.route.element:y=s,d.createElement(va,{match:c,routeContext:{outlet:s,matches:m,isDataRoute:n!=null},children:y})};return n&&(c.route.ErrorBoundary||c.route.errorElement||u===0)?d.createElement(wa,{location:n.location,revalidation:n.revalidation,component:h,error:f,children:w(),routeContext:{outlet:null,matches:m,isDataRoute:!0}}):w()},null)}function Gn(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function Ca(e){let t=d.useContext(ft);return K(t,Gn(e)),t}function Ea(e){let t=d.useContext(on);return K(t,Gn(e)),t}function Sa(e){let t=d.useContext(Te);return K(t,Gn(e)),t}function Xn(e){let t=Sa(e),n=t.matches[t.matches.length-1];return K(n.route.id,`${e} can only be used on routes that contain a unique "id"`),n.route.id}function Ra(){return Xn("useRouteId")}function Pa(){var r;let e=d.useContext(qn),t=Ea("useRouteError"),n=Xn("useRouteError");return e!==void 0?e:(r=t.errors)==null?void 0:r[n]}function Oa(){let{router:e}=Ca("useNavigate"),t=Xn("useNavigate"),n=d.useRef(!1);return ul(()=>{n.current=!0}),d.useCallback(async(o,l={})=>{Pe(n.current,cl),n.current&&(typeof o=="number"?e.navigate(o):await e.navigate(o,{fromRouteId:t,...l}))},[e,t])}var Dr={};function fl(e,t,n){!t&&!Dr[e]&&(Dr[e]=!0,Pe(!1,n))}d.memo(Ta);function Ta({routes:e,future:t,state:n}){return dl(e,void 0,n,t)}function Ia(e){K(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function Da({basename:e="/",children:t=null,location:n,navigationType:r="POP",navigator:o,static:l=!1}){K(!Lt(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let i=e.replace(/^\/*/,"/"),a=d.useMemo(()=>({basename:i,navigator:o,static:l,future:{}}),[i,o,l]);typeof n=="string"&&(n=dt(n));let{pathname:s="/",search:c="",hash:u="",state:f=null,key:p="default"}=n,h=d.useMemo(()=>{let g=_e(s,i);return g==null?null:{location:{pathname:g,search:c,hash:u,state:f,key:p},navigationType:r}},[i,s,c,u,f,p,r]);return Pe(h!=null,`<Router basename="${i}"> is not able to match the URL "${s}${c}${u}" because it does not start with the basename, so the <Router> won't render anything.`),h==null?null:d.createElement(Oe.Provider,{value:a},d.createElement(Dt.Provider,{children:t,value:h}))}function gf({children:e,location:t}){return ya(_n(e),t)}function _n(e,t=[]){let n=[];return d.Children.forEach(e,(r,o)=>{if(!d.isValidElement(r))return;let l=[...t,o];if(r.type===d.Fragment){n.push.apply(n,_n(r.props.children,l));return}K(r.type===Ia,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),K(!r.props.index||!r.props.children,"An index route cannot have child routes.");let i={id:r.props.id||l.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(i.children=_n(r.props.children,l)),n.push(i)}),n}var Yt="get",Jt="application/x-www-form-urlencoded";function ln(e){return e!=null&&typeof e.tagName=="string"}function La(e){return ln(e)&&e.tagName.toLowerCase()==="button"}function Aa(e){return ln(e)&&e.tagName.toLowerCase()==="form"}function $a(e){return ln(e)&&e.tagName.toLowerCase()==="input"}function _a(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}function ja(e,t){return e.button===0&&(!t||t==="_self")&&!_a(e)}var Bt=null;function Fa(){if(Bt===null)try{new FormData(document.createElement("form"),0),Bt=!1}catch{Bt=!0}return Bt}var Ma=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function xn(e){return e!=null&&!Ma.has(e)?(Pe(!1,`"${e}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${Jt}"`),null):e}function Na(e,t){let n,r,o,l,i;if(Aa(e)){let a=e.getAttribute("action");r=a?_e(a,t):null,n=e.getAttribute("method")||Yt,o=xn(e.getAttribute("enctype"))||Jt,l=new FormData(e)}else if(La(e)||$a(e)&&(e.type==="submit"||e.type==="image")){let a=e.form;if(a==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let s=e.getAttribute("formaction")||a.getAttribute("action");if(r=s?_e(s,t):null,n=e.getAttribute("formmethod")||a.getAttribute("method")||Yt,o=xn(e.getAttribute("formenctype"))||xn(a.getAttribute("enctype"))||Jt,l=new FormData(a,e),!Fa()){let{name:c,type:u,value:f}=e;if(u==="image"){let p=c?`${c}.`:"";l.append(`${p}x`,"0"),l.append(`${p}y`,"0")}else c&&l.append(c,f)}}else{if(ln(e))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');n=Yt,r=null,o=Jt,i=e}return l&&o==="text/plain"&&(i=l,l=void 0),{action:r,method:n.toLowerCase(),encType:o,formData:l,body:i}}function Yn(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}async function Ha(e,t){if(e.id in t)return t[e.id];try{let n=await import(e.module);return t[e.id]=n,n}catch(n){return console.error(`Error loading route module \`${e.module}\`, reloading page...`),console.error(n),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function za(e){return e==null?!1:e.href==null?e.rel==="preload"&&typeof e.imageSrcSet=="string"&&typeof e.imageSizes=="string":typeof e.rel=="string"&&typeof e.href=="string"}async function Ba(e,t,n){let r=await Promise.all(e.map(async o=>{let l=t.routes[o.route.id];if(l){let i=await Ha(l,n);return i.links?i.links():[]}return[]}));return qa(r.flat(1).filter(za).filter(o=>o.rel==="stylesheet"||o.rel==="preload").map(o=>o.rel==="stylesheet"?{...o,rel:"prefetch",as:"style"}:{...o,rel:"prefetch"}))}function Lr(e,t,n,r,o,l){let i=(s,c)=>n[c]?s.route.id!==n[c].route.id:!0,a=(s,c)=>{var u;return n[c].pathname!==s.pathname||((u=n[c].route.path)==null?void 0:u.endsWith("*"))&&n[c].params["*"]!==s.params["*"]};return l==="assets"?t.filter((s,c)=>i(s,c)||a(s,c)):l==="data"?t.filter((s,c)=>{var f;let u=r.routes[s.route.id];if(!u||!u.hasLoader)return!1;if(i(s,c)||a(s,c))return!0;if(s.route.shouldRevalidate){let p=s.route.shouldRevalidate({currentUrl:new URL(o.pathname+o.search+o.hash,window.origin),currentParams:((f=n[0])==null?void 0:f.params)||{},nextUrl:new URL(e,window.origin),nextParams:s.params,defaultShouldRevalidate:!0});if(typeof p=="boolean")return p}return!0}):[]}function Ua(e,t,{includeHydrateFallback:n}={}){return Wa(e.map(r=>{let o=t.routes[r.route.id];if(!o)return[];let l=[o.module];return o.clientActionModule&&(l=l.concat(o.clientActionModule)),o.clientLoaderModule&&(l=l.concat(o.clientLoaderModule)),n&&o.hydrateFallbackModule&&(l=l.concat(o.hydrateFallbackModule)),o.imports&&(l=l.concat(o.imports)),l}).flat(1))}function Wa(e){return[...new Set(e)]}function Va(e){let t={},n=Object.keys(e).sort();for(let r of n)t[r]=e[r];return t}function qa(e,t){let n=new Set;return new Set(t),e.reduce((r,o)=>{let l=JSON.stringify(Va(o));return n.has(l)||(n.add(l),r.push({key:l,link:o})),r},[])}function Ga(e,t){let n=typeof e=="string"?new URL(e,typeof window>"u"?"server://singlefetch/":window.location.origin):e;return n.pathname==="/"?n.pathname="_root.data":t&&_e(n.pathname,t)==="/"?n.pathname=`${t.replace(/\/$/,"")}/_root.data`:n.pathname=`${n.pathname.replace(/\/$/,"")}.data`,n}function pl(){let e=d.useContext(ft);return Yn(e,"You must render this element inside a <DataRouterContext.Provider> element"),e}function Xa(){let e=d.useContext(on);return Yn(e,"You must render this element inside a <DataRouterStateContext.Provider> element"),e}var Jn=d.createContext(void 0);Jn.displayName="FrameworkContext";function hl(){let e=d.useContext(Jn);return Yn(e,"You must render this element inside a <HydratedRouter> element"),e}function Ya(e,t){let n=d.useContext(Jn),[r,o]=d.useState(!1),[l,i]=d.useState(!1),{onFocus:a,onBlur:s,onMouseEnter:c,onMouseLeave:u,onTouchStart:f}=t,p=d.useRef(null);d.useEffect(()=>{if(e==="render"&&i(!0),e==="viewport"){let m=y=>{y.forEach(v=>{i(v.isIntersecting)})},w=new IntersectionObserver(m,{threshold:.5});return p.current&&w.observe(p.current),()=>{w.disconnect()}}},[e]),d.useEffect(()=>{if(r){let m=setTimeout(()=>{i(!0)},100);return()=>{clearTimeout(m)}}},[r]);let h=()=>{o(!0)},g=()=>{o(!1),i(!1)};return n?e!=="intent"?[l,p,{}]:[l,p,{onFocus:xt(a,h),onBlur:xt(s,g),onMouseEnter:xt(c,h),onMouseLeave:xt(u,g),onTouchStart:xt(f,h)}]:[!1,p,{}]}function xt(e,t){return n=>{e&&e(n),n.defaultPrevented||t(n)}}function Ja({page:e,...t}){let{router:n}=pl(),r=d.useMemo(()=>nl(n.routes,e,n.basename),[n.routes,e,n.basename]);return r?d.createElement(Qa,{page:e,matches:r,...t}):null}function Ka(e){let{manifest:t,routeModules:n}=hl(),[r,o]=d.useState([]);return d.useEffect(()=>{let l=!1;return Ba(e,t,n).then(i=>{l||o(i)}),()=>{l=!0}},[e,t,n]),r}function Qa({page:e,matches:t,...n}){let r=Ye(),{manifest:o,routeModules:l}=hl(),{basename:i}=pl(),{loaderData:a,matches:s}=Xa(),c=d.useMemo(()=>Lr(e,t,s,o,r,"data"),[e,t,s,o,r]),u=d.useMemo(()=>Lr(e,t,s,o,r,"assets"),[e,t,s,o,r]),f=d.useMemo(()=>{if(e===r.pathname+r.search+r.hash)return[];let g=new Set,m=!1;if(t.forEach(y=>{var x;let v=o.routes[y.route.id];!v||!v.hasLoader||(!c.some(S=>S.route.id===y.route.id)&&y.route.id in a&&((x=l[y.route.id])!=null&&x.shouldRevalidate)||v.hasClientLoader?m=!0:g.add(y.route.id))}),g.size===0)return[];let w=Ga(e,i);return m&&g.size>0&&w.searchParams.set("_routes",t.filter(y=>g.has(y.route.id)).map(y=>y.route.id).join(",")),[w.pathname+w.search]},[i,a,r,o,c,t,e,l]),p=d.useMemo(()=>Ua(u,o),[u,o]),h=Ka(u);return d.createElement(d.Fragment,null,f.map(g=>d.createElement("link",{key:g,rel:"prefetch",as:"fetch",href:g,...n})),p.map(g=>d.createElement("link",{key:g,rel:"modulepreload",href:g,...n})),h.map(({key:g,link:m})=>d.createElement("link",{key:g,...m})))}function Za(...e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}var gl=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{gl&&(window.__reactRouterVersion="7.4.1")}catch{}function mf({basename:e,children:t,window:n}){let r=d.useRef();r.current==null&&(r.current=Bi({window:n,v5Compat:!0}));let o=r.current,[l,i]=d.useState({action:o.action,location:o.location}),a=d.useCallback(s=>{d.startTransition(()=>i(s))},[i]);return d.useLayoutEffect(()=>o.listen(a),[o,a]),d.createElement(Da,{basename:e,children:t,location:l.location,navigationType:l.action,navigator:o})}var ml=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,yl=d.forwardRef(function({onClick:t,discover:n="render",prefetch:r="none",relative:o,reloadDocument:l,replace:i,state:a,target:s,to:c,preventScrollReset:u,viewTransition:f,...p},h){let{basename:g}=d.useContext(Oe),m=typeof c=="string"&&ml.test(c),w,y=!1;if(typeof c=="string"&&m&&(w=c,gl))try{let M=new URL(window.location.href),_=c.startsWith("//")?new URL(M.protocol+c):new URL(c),P=_e(_.pathname,g);_.origin===M.origin&&P!=null?c=P+_.search+_.hash:y=!0}catch{Pe(!1,`<Link to="${c}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}let v=ha(c,{relative:o}),[x,S,I]=Ya(r,p),F=rs(c,{replace:i,state:a,target:s,preventScrollReset:u,relative:o,viewTransition:f});function T(M){t&&t(M),M.defaultPrevented||F(M)}let $=d.createElement("a",{...p,...I,href:w||v,onClick:y||l?t:T,ref:Za(h,S),target:s,"data-discover":!m&&n==="render"?"true":void 0});return x&&!m?d.createElement(d.Fragment,null,$,d.createElement(Ja,{page:v})):$});yl.displayName="Link";var es=d.forwardRef(function({"aria-current":t="page",caseSensitive:n=!1,className:r="",end:o=!1,style:l,to:i,viewTransition:a,children:s,...c},u){let f=At(i,{relative:c.relative}),p=Ye(),h=d.useContext(on),{navigator:g,basename:m}=d.useContext(Oe),w=h!=null&&ss(f)&&a===!0,y=g.encodeLocation?g.encodeLocation(f).pathname:f.pathname,v=p.pathname,x=h&&h.navigation&&h.navigation.location?h.navigation.location.pathname:null;n||(v=v.toLowerCase(),x=x?x.toLowerCase():null,y=y.toLowerCase()),x&&m&&(x=_e(x,m)||x);const S=y!=="/"&&y.endsWith("/")?y.length-1:y.length;let I=v===y||!o&&v.startsWith(y)&&v.charAt(S)==="/",F=x!=null&&(x===y||!o&&x.startsWith(y)&&x.charAt(y.length)==="/"),T={isActive:I,isPending:F,isTransitioning:w},$=I?t:void 0,M;typeof r=="function"?M=r(T):M=[r,I?"active":null,F?"pending":null,w?"transitioning":null].filter(Boolean).join(" ");let _=typeof l=="function"?l(T):l;return d.createElement(yl,{...c,"aria-current":$,className:M,ref:u,style:_,to:i,viewTransition:a},typeof s=="function"?s(T):s)});es.displayName="NavLink";var ts=d.forwardRef(({discover:e="render",fetcherKey:t,navigate:n,reloadDocument:r,replace:o,state:l,method:i=Yt,action:a,onSubmit:s,relative:c,preventScrollReset:u,viewTransition:f,...p},h)=>{let g=is(),m=as(a,{relative:c}),w=i.toLowerCase()==="get"?"get":"post",y=typeof a=="string"&&ml.test(a),v=x=>{if(s&&s(x),x.defaultPrevented)return;x.preventDefault();let S=x.nativeEvent.submitter,I=(S==null?void 0:S.getAttribute("formmethod"))||i;g(S||x.currentTarget,{fetcherKey:t,method:I,navigate:n,replace:o,state:l,relative:c,preventScrollReset:u,viewTransition:f})};return d.createElement("form",{ref:h,method:w,action:m,onSubmit:r?s:v,...p,"data-discover":!y&&e==="render"?"true":void 0})});ts.displayName="Form";function ns(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function bl(e){let t=d.useContext(ft);return K(t,ns(e)),t}function rs(e,{target:t,replace:n,state:r,preventScrollReset:o,relative:l,viewTransition:i}={}){let a=ga(),s=Ye(),c=At(e,{relative:l});return d.useCallback(u=>{if(ja(u,t)){u.preventDefault();let f=n!==void 0?n:Ot(s)===Ot(c);a(e,{replace:f,state:r,preventScrollReset:o,relative:l,viewTransition:i})}},[s,a,c,n,r,t,e,o,l,i])}var os=0,ls=()=>`__${String(++os)}__`;function is(){let{router:e}=bl("useSubmit"),{basename:t}=d.useContext(Oe),n=Ra();return d.useCallback(async(r,o={})=>{let{action:l,method:i,encType:a,formData:s,body:c}=Na(r,t);if(o.navigate===!1){let u=o.fetcherKey||ls();await e.fetch(u,n,o.action||l,{preventScrollReset:o.preventScrollReset,formData:s,body:c,formMethod:o.method||i,formEncType:o.encType||a,flushSync:o.flushSync})}else await e.navigate(o.action||l,{preventScrollReset:o.preventScrollReset,formData:s,body:c,formMethod:o.method||i,formEncType:o.encType||a,replace:o.replace,state:o.state,fromRouteId:n,flushSync:o.flushSync,viewTransition:o.viewTransition})},[e,t,n])}function as(e,{relative:t}={}){let{basename:n}=d.useContext(Oe),r=d.useContext(Te);K(r,"useFormAction must be used inside a RouteContext");let[o]=r.matches.slice(-1),l={...At(e||".",{relative:t})},i=Ye();if(e==null){l.search=i.search;let a=new URLSearchParams(l.search),s=a.getAll("index");if(s.some(u=>u==="")){a.delete("index"),s.filter(f=>f).forEach(f=>a.append("index",f));let u=a.toString();l.search=u?`?${u}`:""}}return(!e||e===".")&&o.route.index&&(l.search=l.search?l.search.replace(/^\?/,"?index&"):"?index"),n!=="/"&&(l.pathname=l.pathname==="/"?n:$e([n,l.pathname])),Ot(l)}function ss(e,t={}){let n=d.useContext(sl);K(n!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=bl("useViewTransitionState"),o=At(e,{relative:t.relative});if(!n.isTransitioning)return!1;let l=_e(n.currentLocation.pathname,r)||n.currentLocation.pathname,i=_e(n.nextLocation.pathname,r)||n.nextLocation.pathname;return Zt(o.pathname,i)!=null||Zt(o.pathname,l)!=null}new TextEncoder;function cs(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const us=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,ds=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,fs={};function Ar(e,t){return(fs.jsx?ds:us).test(e)}const ps=/[ \t\n\f\r]/g;function hs(e){return typeof e=="object"?e.type==="text"?$r(e.value):!1:$r(e)}function $r(e){return e.replace(ps,"")===""}class $t{constructor(t,n,r){this.normal=n,this.property=t,r&&(this.space=r)}}$t.prototype.normal={};$t.prototype.property={};$t.prototype.space=void 0;function xl(e,t){const n={},r={};for(const o of e)Object.assign(n,o.property),Object.assign(r,o.normal);return new $t(n,r,t)}function jn(e){return e.toLowerCase()}class ce{constructor(t,n){this.attribute=n,this.property=t}}ce.prototype.attribute="";ce.prototype.booleanish=!1;ce.prototype.boolean=!1;ce.prototype.commaOrSpaceSeparated=!1;ce.prototype.commaSeparated=!1;ce.prototype.defined=!1;ce.prototype.mustUseProperty=!1;ce.prototype.number=!1;ce.prototype.overloadedBoolean=!1;ce.prototype.property="";ce.prototype.spaceSeparated=!1;ce.prototype.space=void 0;let gs=0;const j=Je(),Z=Je(),wl=Je(),k=Je(),X=Je(),at=Je(),pe=Je();function Je(){return 2**++gs}const Fn=Object.freeze(Object.defineProperty({__proto__:null,boolean:j,booleanish:Z,commaOrSpaceSeparated:pe,commaSeparated:at,number:k,overloadedBoolean:wl,spaceSeparated:X},Symbol.toStringTag,{value:"Module"})),wn=Object.keys(Fn);class Kn extends ce{constructor(t,n,r,o){let l=-1;if(super(t,n),_r(this,"space",o),typeof r=="number")for(;++l<wn.length;){const i=wn[l];_r(this,wn[l],(r&Fn[i])===Fn[i])}}}Kn.prototype.defined=!0;function _r(e,t,n){n&&(e[t]=n)}function pt(e){const t={},n={};for(const[r,o]of Object.entries(e.properties)){const l=new Kn(r,e.transform(e.attributes||{},r),o,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(l.mustUseProperty=!0),t[r]=l,n[jn(r)]=r,n[jn(l.attribute)]=r}return new $t(t,n,e.space)}const vl=pt({properties:{ariaActiveDescendant:null,ariaAtomic:Z,ariaAutoComplete:null,ariaBusy:Z,ariaChecked:Z,ariaColCount:k,ariaColIndex:k,ariaColSpan:k,ariaControls:X,ariaCurrent:null,ariaDescribedBy:X,ariaDetails:null,ariaDisabled:Z,ariaDropEffect:X,ariaErrorMessage:null,ariaExpanded:Z,ariaFlowTo:X,ariaGrabbed:Z,ariaHasPopup:null,ariaHidden:Z,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:X,ariaLevel:k,ariaLive:null,ariaModal:Z,ariaMultiLine:Z,ariaMultiSelectable:Z,ariaOrientation:null,ariaOwns:X,ariaPlaceholder:null,ariaPosInSet:k,ariaPressed:Z,ariaReadOnly:Z,ariaRelevant:null,ariaRequired:Z,ariaRoleDescription:X,ariaRowCount:k,ariaRowIndex:k,ariaRowSpan:k,ariaSelected:Z,ariaSetSize:k,ariaSort:null,ariaValueMax:k,ariaValueMin:k,ariaValueNow:k,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function kl(e,t){return t in e?e[t]:t}function Cl(e,t){return kl(e,t.toLowerCase())}const ms=pt({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:at,acceptCharset:X,accessKey:X,action:null,allow:null,allowFullScreen:j,allowPaymentRequest:j,allowUserMedia:j,alt:null,as:null,async:j,autoCapitalize:null,autoComplete:X,autoFocus:j,autoPlay:j,blocking:X,capture:null,charSet:null,checked:j,cite:null,className:X,cols:k,colSpan:null,content:null,contentEditable:Z,controls:j,controlsList:X,coords:k|at,crossOrigin:null,data:null,dateTime:null,decoding:null,default:j,defer:j,dir:null,dirName:null,disabled:j,download:wl,draggable:Z,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:j,formTarget:null,headers:X,height:k,hidden:j,high:k,href:null,hrefLang:null,htmlFor:X,httpEquiv:X,id:null,imageSizes:null,imageSrcSet:null,inert:j,inputMode:null,integrity:null,is:null,isMap:j,itemId:null,itemProp:X,itemRef:X,itemScope:j,itemType:X,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:j,low:k,manifest:null,max:null,maxLength:k,media:null,method:null,min:null,minLength:k,multiple:j,muted:j,name:null,nonce:null,noModule:j,noValidate:j,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:j,optimum:k,pattern:null,ping:X,placeholder:null,playsInline:j,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:j,referrerPolicy:null,rel:X,required:j,reversed:j,rows:k,rowSpan:k,sandbox:X,scope:null,scoped:j,seamless:j,selected:j,shadowRootClonable:j,shadowRootDelegatesFocus:j,shadowRootMode:null,shape:null,size:k,sizes:null,slot:null,span:k,spellCheck:Z,src:null,srcDoc:null,srcLang:null,srcSet:null,start:k,step:null,style:null,tabIndex:k,target:null,title:null,translate:null,type:null,typeMustMatch:j,useMap:null,value:Z,width:k,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:X,axis:null,background:null,bgColor:null,border:k,borderColor:null,bottomMargin:k,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:j,declare:j,event:null,face:null,frame:null,frameBorder:null,hSpace:k,leftMargin:k,link:null,longDesc:null,lowSrc:null,marginHeight:k,marginWidth:k,noResize:j,noHref:j,noShade:j,noWrap:j,object:null,profile:null,prompt:null,rev:null,rightMargin:k,rules:null,scheme:null,scrolling:Z,standby:null,summary:null,text:null,topMargin:k,valueType:null,version:null,vAlign:null,vLink:null,vSpace:k,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:j,disableRemotePlayback:j,prefix:null,property:null,results:k,security:null,unselectable:null},space:"html",transform:Cl}),ys=pt({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:pe,accentHeight:k,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:k,amplitude:k,arabicForm:null,ascent:k,attributeName:null,attributeType:null,azimuth:k,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:k,by:null,calcMode:null,capHeight:k,className:X,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:k,diffuseConstant:k,direction:null,display:null,dur:null,divisor:k,dominantBaseline:null,download:j,dx:null,dy:null,edgeMode:null,editable:null,elevation:k,enableBackground:null,end:null,event:null,exponent:k,externalResourcesRequired:null,fill:null,fillOpacity:k,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:at,g2:at,glyphName:at,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:k,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:k,horizOriginX:k,horizOriginY:k,id:null,ideographic:k,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:k,k,k1:k,k2:k,k3:k,k4:k,kernelMatrix:pe,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:k,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:k,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:k,overlineThickness:k,paintOrder:null,panose1:null,path:null,pathLength:k,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:X,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:k,pointsAtY:k,pointsAtZ:k,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:pe,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:pe,rev:pe,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:pe,requiredFeatures:pe,requiredFonts:pe,requiredFormats:pe,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:k,specularExponent:k,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:k,strikethroughThickness:k,string:null,stroke:null,strokeDashArray:pe,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:k,strokeOpacity:k,strokeWidth:null,style:null,surfaceScale:k,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:pe,tabIndex:k,tableValues:null,target:null,targetX:k,targetY:k,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:pe,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:k,underlineThickness:k,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:k,values:null,vAlphabetic:k,vMathematical:k,vectorEffect:null,vHanging:k,vIdeographic:k,version:null,vertAdvY:k,vertOriginX:k,vertOriginY:k,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:k,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:kl}),El=pt({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),Sl=pt({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:Cl}),Rl=pt({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),bs={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},xs=/[A-Z]/g,jr=/-[a-z]/g,ws=/^data[-\w.:]+$/i;function vs(e,t){const n=jn(t);let r=t,o=ce;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&ws.test(t)){if(t.charAt(4)==="-"){const l=t.slice(5).replace(jr,Cs);r="data"+l.charAt(0).toUpperCase()+l.slice(1)}else{const l=t.slice(4);if(!jr.test(l)){let i=l.replace(xs,ks);i.charAt(0)!=="-"&&(i="-"+i),t="data"+i}}o=Kn}return new o(r,t)}function ks(e){return"-"+e.toLowerCase()}function Cs(e){return e.charAt(1).toUpperCase()}const Es=xl([vl,ms,El,Sl,Rl],"html"),Qn=xl([vl,ys,El,Sl,Rl],"svg");function Ss(e){return e.join(" ").trim()}var lt={},vn,Fr;function Rs(){if(Fr)return vn;Fr=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,o=/^:\s*/,l=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,i=/^[;\s]*/,a=/^\s+|\s+$/g,s=`
`,c="/",u="*",f="",p="comment",h="declaration";vn=function(m,w){if(typeof m!="string")throw new TypeError("First argument must be a string");if(!m)return[];w=w||{};var y=1,v=1;function x(R){var O=R.match(t);O&&(y+=O.length);var Y=R.lastIndexOf(s);v=~Y?R.length-Y:v+R.length}function S(){var R={line:y,column:v};return function(O){return O.position=new I(R),$(),O}}function I(R){this.start=R,this.end={line:y,column:v},this.source=w.source}I.prototype.content=m;function F(R){var O=new Error(w.source+":"+y+":"+v+": "+R);if(O.reason=R,O.filename=w.source,O.line=y,O.column=v,O.source=m,!w.silent)throw O}function T(R){var O=R.exec(m);if(O){var Y=O[0];return x(Y),m=m.slice(Y.length),O}}function $(){T(n)}function M(R){var O;for(R=R||[];O=_();)O!==!1&&R.push(O);return R}function _(){var R=S();if(!(c!=m.charAt(0)||u!=m.charAt(1))){for(var O=2;f!=m.charAt(O)&&(u!=m.charAt(O)||c!=m.charAt(O+1));)++O;if(O+=2,f===m.charAt(O-1))return F("End of comment missing");var Y=m.slice(2,O-2);return v+=2,x(Y),m=m.slice(O),v+=2,R({type:p,comment:Y})}}function P(){var R=S(),O=T(r);if(O){if(_(),!T(o))return F("property missing ':'");var Y=T(l),re=R({type:h,property:g(O[0].replace(e,f)),value:Y?g(Y[0].replace(e,f)):f});return T(i),re}}function N(){var R=[];M(R);for(var O;O=P();)O!==!1&&(R.push(O),M(R));return R}return $(),N()};function g(m){return m?m.replace(a,f):f}return vn}var Mr;function Ps(){if(Mr)return lt;Mr=1;var e=lt&&lt.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(lt,"__esModule",{value:!0}),lt.default=n;var t=e(Rs());function n(r,o){var l=null;if(!r||typeof r!="string")return l;var i=(0,t.default)(r),a=typeof o=="function";return i.forEach(function(s){if(s.type==="declaration"){var c=s.property,u=s.value;a?o(c,u,s):u&&(l=l||{},l[c]=u)}}),l}return lt}var wt={},Nr;function Os(){if(Nr)return wt;Nr=1,Object.defineProperty(wt,"__esModule",{value:!0}),wt.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,o=/^-(ms)-/,l=function(c){return!c||n.test(c)||e.test(c)},i=function(c,u){return u.toUpperCase()},a=function(c,u){return"".concat(u,"-")},s=function(c,u){return u===void 0&&(u={}),l(c)?c:(c=c.toLowerCase(),u.reactCompat?c=c.replace(o,a):c=c.replace(r,a),c.replace(t,i))};return wt.camelCase=s,wt}var vt,Hr;function Ts(){if(Hr)return vt;Hr=1;var e=vt&&vt.__importDefault||function(o){return o&&o.__esModule?o:{default:o}},t=e(Ps()),n=Os();function r(o,l){var i={};return!o||typeof o!="string"||(0,t.default)(o,function(a,s){a&&s&&(i[(0,n.camelCase)(a,l)]=s)}),i}return r.default=r,vt=r,vt}var Is=Ts();const Ds=Qo(Is),Pl=Ol("end"),Zn=Ol("start");function Ol(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function Ls(e){const t=Zn(e),n=Pl(e);if(t&&n)return{start:t,end:n}}function Et(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?zr(e.position):"start"in e||"end"in e?zr(e):"line"in e||"column"in e?Mn(e):""}function Mn(e){return Br(e&&e.line)+":"+Br(e&&e.column)}function zr(e){return Mn(e&&e.start)+"-"+Mn(e&&e.end)}function Br(e){return e&&typeof e=="number"?e:1}class ne extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let o="",l={},i=!1;if(n&&("line"in n&&"column"in n?l={place:n}:"start"in n&&"end"in n?l={place:n}:"type"in n?l={ancestors:[n],place:n.position}:l={...n}),typeof t=="string"?o=t:!l.cause&&t&&(i=!0,o=t.message,l.cause=t),!l.ruleId&&!l.source&&typeof r=="string"){const s=r.indexOf(":");s===-1?l.ruleId=r:(l.source=r.slice(0,s),l.ruleId=r.slice(s+1))}if(!l.place&&l.ancestors&&l.ancestors){const s=l.ancestors[l.ancestors.length-1];s&&(l.place=s.position)}const a=l.place&&"start"in l.place?l.place.start:l.place;this.ancestors=l.ancestors||void 0,this.cause=l.cause||void 0,this.column=a?a.column:void 0,this.fatal=void 0,this.file,this.message=o,this.line=a?a.line:void 0,this.name=Et(l.place)||"1:1",this.place=l.place||void 0,this.reason=this.message,this.ruleId=l.ruleId||void 0,this.source=l.source||void 0,this.stack=i&&l.cause&&typeof l.cause.stack=="string"?l.cause.stack:"",this.actual,this.expected,this.note,this.url}}ne.prototype.file="";ne.prototype.name="";ne.prototype.reason="";ne.prototype.message="";ne.prototype.stack="";ne.prototype.column=void 0;ne.prototype.line=void 0;ne.prototype.ancestors=void 0;ne.prototype.cause=void 0;ne.prototype.fatal=void 0;ne.prototype.place=void 0;ne.prototype.ruleId=void 0;ne.prototype.source=void 0;const er={}.hasOwnProperty,As=new Map,$s=/[A-Z]/g,_s=new Set(["table","tbody","thead","tfoot","tr"]),js=new Set(["td","th"]),Tl="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function Fs(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=Vs(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=Ws(n,t.jsx,t.jsxs)}const o={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?Qn:Es,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},l=Il(o,e,void 0);return l&&typeof l!="string"?l:o.create(e,o.Fragment,{children:l||void 0},void 0)}function Il(e,t,n){if(t.type==="element")return Ms(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return Ns(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return zs(e,t,n);if(t.type==="mdxjsEsm")return Hs(e,t);if(t.type==="root")return Bs(e,t,n);if(t.type==="text")return Us(e,t)}function Ms(e,t,n){const r=e.schema;let o=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(o=Qn,e.schema=o),e.ancestors.push(t);const l=Ll(e,t.tagName,!1),i=qs(e,t);let a=nr(e,t);return _s.has(t.tagName)&&(a=a.filter(function(s){return typeof s=="string"?!hs(s):!0})),Dl(e,i,l,t),tr(i,a),e.ancestors.pop(),e.schema=r,e.create(t,l,i,n)}function Ns(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return Ct(r.type==="ExpressionStatement"),e.evaluater.evaluateExpression(r.expression)}Tt(e,t.position)}function Hs(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);Tt(e,t.position)}function zs(e,t,n){const r=e.schema;let o=r;t.name==="svg"&&r.space==="html"&&(o=Qn,e.schema=o),e.ancestors.push(t);const l=t.name===null?e.Fragment:Ll(e,t.name,!0),i=Gs(e,t),a=nr(e,t);return Dl(e,i,l,t),tr(i,a),e.ancestors.pop(),e.schema=r,e.create(t,l,i,n)}function Bs(e,t,n){const r={};return tr(r,nr(e,t)),e.create(t,e.Fragment,r,n)}function Us(e,t){return t.value}function Dl(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function tr(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function Ws(e,t,n){return r;function r(o,l,i,a){const c=Array.isArray(i.children)?n:t;return a?c(l,i,a):c(l,i)}}function Vs(e,t){return n;function n(r,o,l,i){const a=Array.isArray(l.children),s=Zn(r);return t(o,l,i,a,{columnNumber:s?s.column-1:void 0,fileName:e,lineNumber:s?s.line:void 0},void 0)}}function qs(e,t){const n={};let r,o;for(o in t.properties)if(o!=="children"&&er.call(t.properties,o)){const l=Xs(e,o,t.properties[o]);if(l){const[i,a]=l;e.tableCellAlignToStyle&&i==="align"&&typeof a=="string"&&js.has(t.tagName)?r=a:n[i]=a}}if(r){const l=n.style||(n.style={});l[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function Gs(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const l=r.data.estree.body[0];Ct(l.type==="ExpressionStatement");const i=l.expression;Ct(i.type==="ObjectExpression");const a=i.properties[0];Ct(a.type==="SpreadElement"),Object.assign(n,e.evaluater.evaluateExpression(a.argument))}else Tt(e,t.position);else{const o=r.name;let l;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const a=r.value.data.estree.body[0];Ct(a.type==="ExpressionStatement"),l=e.evaluater.evaluateExpression(a.expression)}else Tt(e,t.position);else l=r.value===null?!0:r.value;n[o]=l}return n}function nr(e,t){const n=[];let r=-1;const o=e.passKeys?new Map:As;for(;++r<t.children.length;){const l=t.children[r];let i;if(e.passKeys){const s=l.type==="element"?l.tagName:l.type==="mdxJsxFlowElement"||l.type==="mdxJsxTextElement"?l.name:void 0;if(s){const c=o.get(s)||0;i=s+"-"+c,o.set(s,c+1)}}const a=Il(e,l,i);a!==void 0&&n.push(a)}return n}function Xs(e,t,n){const r=vs(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?cs(n):Ss(n)),r.property==="style"){let o=typeof n=="object"?n:Ys(e,String(n));return e.stylePropertyNameCase==="css"&&(o=Js(o)),["style",o]}return[e.elementAttributeNameCase==="react"&&r.space?bs[r.property]||r.property:r.attribute,n]}}function Ys(e,t){try{return Ds(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const r=n,o=new ne("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw o.file=e.filePath||void 0,o.url=Tl+"#cannot-parse-style-attribute",o}}function Ll(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const o=t.split(".");let l=-1,i;for(;++l<o.length;){const a=Ar(o[l])?{type:"Identifier",name:o[l]}:{type:"Literal",value:o[l]};i=i?{type:"MemberExpression",object:i,property:a,computed:!!(l&&a.type==="Literal"),optional:!1}:a}r=i}else r=Ar(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const o=r.value;return er.call(e.components,o)?e.components[o]:o}if(e.evaluater)return e.evaluater.evaluateExpression(r);Tt(e)}function Tt(e,t){const n=new ne("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=Tl+"#cannot-handle-mdx-estrees-without-createevaluater",n}function Js(e){const t={};let n;for(n in e)er.call(e,n)&&(t[Ks(n)]=e[n]);return t}function Ks(e){let t=e.replace($s,Qs);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function Qs(e){return"-"+e.toLowerCase()}const kn={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]};function Zs(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}const ec={tokenize:tc};function tc(e){const t=e.attempt(this.parser.constructs.contentInitial,r,o);let n;return t;function r(a){if(a===null){e.consume(a);return}return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),Wn(e,t,"linePrefix")}function o(a){return e.enter("paragraph"),l(a)}function l(a){const s=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=s),n=s,i(a)}function i(a){if(a===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(a);return}return Vn(a)?(e.consume(a),e.exit("chunkText"),l):(e.consume(a),i)}}const nc={tokenize:rc},Ur={tokenize:oc};function rc(e){const t=this,n=[];let r=0,o,l,i;return a;function a(x){if(r<n.length){const S=n[r];return t.containerState=S[1],e.attempt(S[0].continuation,s,c)(x)}return c(x)}function s(x){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,o&&v();const S=t.events.length;let I=S,F;for(;I--;)if(t.events[I][0]==="exit"&&t.events[I][1].type==="chunkFlow"){F=t.events[I][1].end;break}y(r);let T=S;for(;T<t.events.length;)t.events[T][1].end={...F},T++;return Qt(t.events,I+1,0,t.events.slice(S)),t.events.length=T,c(x)}return a(x)}function c(x){if(r===n.length){if(!o)return p(x);if(o.currentConstruct&&o.currentConstruct.concrete)return g(x);t.interrupt=!!(o.currentConstruct&&!o._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(Ur,u,f)(x)}function u(x){return o&&v(),y(r),p(x)}function f(x){return t.parser.lazy[t.now().line]=r!==n.length,i=t.now().offset,g(x)}function p(x){return t.containerState={},e.attempt(Ur,h,g)(x)}function h(x){return r++,n.push([t.currentConstruct,t.containerState]),p(x)}function g(x){if(x===null){o&&v(),y(0),e.consume(x);return}return o=o||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:o,contentType:"flow",previous:l}),m(x)}function m(x){if(x===null){w(e.exit("chunkFlow"),!0),y(0),e.consume(x);return}return Vn(x)?(e.consume(x),w(e.exit("chunkFlow")),r=0,t.interrupt=void 0,a):(e.consume(x),m)}function w(x,S){const I=t.sliceStream(x);if(S&&I.push(null),x.previous=l,l&&(l.next=x),l=x,o.defineSkip(x.start),o.write(I),t.parser.lazy[x.start.line]){let F=o.events.length;for(;F--;)if(o.events[F][1].start.offset<i&&(!o.events[F][1].end||o.events[F][1].end.offset>i))return;const T=t.events.length;let $=T,M,_;for(;$--;)if(t.events[$][0]==="exit"&&t.events[$][1].type==="chunkFlow"){if(M){_=t.events[$][1].end;break}M=!0}for(y(r),F=T;F<t.events.length;)t.events[F][1].end={..._},F++;Qt(t.events,$+1,0,t.events.slice(T)),t.events.length=F}}function y(x){let S=n.length;for(;S-- >x;){const I=n[S];t.containerState=I[1],I[0].exit.call(t,e)}n.length=x}function v(){o.write([null]),l=void 0,o=void 0,t.containerState._closeFlow=void 0}}function oc(e,t,n){return Wn(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}const lc={tokenize:ic};function ic(e){const t=this,n=e.attempt(yi,r,e.attempt(this.parser.constructs.flowInitial,o,Wn(e,e.attempt(this.parser.constructs.flow,o,e.attempt(bi,o)),"linePrefix")));return n;function r(l){if(l===null){e.consume(l);return}return e.enter("lineEndingBlank"),e.consume(l),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function o(l){if(l===null){e.consume(l);return}return e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const ac={resolveAll:$l()},sc=Al("string"),cc=Al("text");function Al(e){return{resolveAll:$l(e==="text"?uc:void 0),tokenize:t};function t(n){const r=this,o=this.parser.constructs[e],l=n.attempt(o,i,a);return i;function i(u){return c(u)?l(u):a(u)}function a(u){if(u===null){n.consume(u);return}return n.enter("data"),n.consume(u),s}function s(u){return c(u)?(n.exit("data"),l(u)):(n.consume(u),s)}function c(u){if(u===null)return!0;const f=o[u];let p=-1;if(f)for(;++p<f.length;){const h=f[p];if(!h.previous||h.previous.call(r,r.previous))return!0}return!1}}}function $l(e){return t;function t(n,r){let o=-1,l;for(;++o<=n.length;)l===void 0?n[o]&&n[o][1].type==="data"&&(l=o,o++):(!n[o]||n[o][1].type!=="data")&&(o!==l+2&&(n[l][1].end=n[o-1][1].end,n.splice(l+2,o-l-2),o=l+2),l=void 0);return e?e(n,r):n}}function uc(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],o=t.sliceStream(r);let l=o.length,i=-1,a=0,s;for(;l--;){const c=o[l];if(typeof c=="string"){for(i=c.length;c.charCodeAt(i-1)===32;)a++,i--;if(i)break;i=-1}else if(c===-2)s=!0,a++;else if(c!==-1){l++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(a=0),a){const c={type:n===e.length||s||a<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:l?i:r.start._bufferIndex+i,_index:r.start._index+l,line:r.end.line,column:r.end.column-a,offset:r.end.offset-a},end:{...r.end}};r.end={...c.start},r.start.offset===r.end.offset?Object.assign(r,c):(e.splice(n,0,["enter",c,t],["exit",c,t]),n+=2)}n++}return e}const dc={42:fe,43:fe,45:fe,48:fe,49:fe,50:fe,51:fe,52:fe,53:fe,54:fe,55:fe,56:fe,57:fe,62:xi},fc={91:wi},pc={[-2]:fn,[-1]:fn,32:fn},hc={35:ki,42:pn,45:[Er,pn],60:vi,61:Er,95:pn,96:Cr,126:Cr},gc={38:el,92:Zo},mc={[-5]:hn,[-4]:hn,[-3]:hn,33:Ti,38:el,42:An,60:[Pi,Oi],91:Ri,92:[Si,Zo],93:Ei,95:An,96:Ci},yc={null:[An,ac]},bc={null:[42,95]},xc={null:[]},wc=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:bc,contentInitial:fc,disable:xc,document:dc,flow:hc,flowInitial:pc,insideSpan:yc,string:gc,text:mc},Symbol.toStringTag,{value:"Module"}));function vc(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const o={},l=[];let i=[],a=[];const s={attempt:T(I),check:T(F),consume:v,enter:x,exit:S,interrupt:T(F,{interrupt:!0})},c={code:null,containerState:{},defineSkip:m,events:[],now:g,parser:e,previous:null,sliceSerialize:p,sliceStream:h,write:f};let u=t.tokenize.call(c,s);return t.resolveAll&&l.push(t),c;function f(P){return i=Ii(i,P),w(),i[i.length-1]!==null?[]:($(t,0),c.events=Di(l,c.events,c),c.events)}function p(P,N){return Cc(h(P),N)}function h(P){return kc(i,P)}function g(){const{_bufferIndex:P,_index:N,line:R,column:O,offset:Y}=r;return{_bufferIndex:P,_index:N,line:R,column:O,offset:Y}}function m(P){o[P.line]=P.column,_()}function w(){let P;for(;r._index<i.length;){const N=i[r._index];if(typeof N=="string")for(P=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===P&&r._bufferIndex<N.length;)y(N.charCodeAt(r._bufferIndex));else y(N)}}function y(P){u=u(P)}function v(P){Vn(P)?(r.line++,r.column=1,r.offset+=P===-3?2:1,_()):P!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===i[r._index].length&&(r._bufferIndex=-1,r._index++)),c.previous=P}function x(P,N){const R=N||{};return R.type=P,R.start=g(),c.events.push(["enter",R,c]),a.push(R),R}function S(P){const N=a.pop();return N.end=g(),c.events.push(["exit",N,c]),N}function I(P,N){$(P,N.from)}function F(P,N){N.restore()}function T(P,N){return R;function R(O,Y,re){let he,ve,je,Ie;return Array.isArray(O)?oe(O):"tokenize"in O?oe([O]):We(O);function We(J){return Le;function Le(ge){const me=ge!==null&&J[ge],Ce=ge!==null&&J.null,de=[...Array.isArray(me)?me:me?[me]:[],...Array.isArray(Ce)?Ce:Ce?[Ce]:[]];return oe(de)(ge)}}function oe(J){return he=J,ve=0,J.length===0?re:De(J[ve])}function De(J){return Le;function Le(ge){return Ie=M(),je=J,J.partial||(c.currentConstruct=J),J.name&&c.parser.constructs.disable.null.includes(J.name)?ke():J.tokenize.call(N?Object.assign(Object.create(c),N):c,s,ue,ke)(ge)}}function ue(J){return P(je,Ie),Y}function ke(J){return Ie.restore(),++ve<he.length?De(he[ve]):re}}}function $(P,N){P.resolveAll&&!l.includes(P)&&l.push(P),P.resolve&&Qt(c.events,N,c.events.length-N,P.resolve(c.events.slice(N),c)),P.resolveTo&&(c.events=P.resolveTo(c.events,c))}function M(){const P=g(),N=c.previous,R=c.currentConstruct,O=c.events.length,Y=Array.from(a);return{from:O,restore:re};function re(){r=P,c.previous=N,c.currentConstruct=R,c.events.length=O,a=Y,_()}}function _(){r.line in o&&r.column<2&&(r.column=o[r.line],r.offset+=o[r.line]-1)}}function kc(e,t){const n=t.start._index,r=t.start._bufferIndex,o=t.end._index,l=t.end._bufferIndex;let i;if(n===o)i=[e[n].slice(r,l)];else{if(i=e.slice(n,o),r>-1){const a=i[0];typeof a=="string"?i[0]=a.slice(r):i.shift()}l>0&&i.push(e[o].slice(0,l))}return i}function Cc(e,t){let n=-1;const r=[];let o;for(;++n<e.length;){const l=e[n];let i;if(typeof l=="string")i=l;else switch(l){case-5:{i="\r";break}case-4:{i=`
`;break}case-3:{i=`\r
`;break}case-2:{i=t?" ":"	";break}case-1:{if(!t&&o)continue;i=" ";break}default:i=String.fromCharCode(l)}o=l===-2,r.push(i)}return r.join("")}function Ec(e){const r={constructs:Li([wc,...(e||{}).extensions||[]]),content:o(ec),defined:[],document:o(nc),flow:o(lc),lazy:{},string:o(sc),text:o(cc)};return r;function o(l){return i;function i(a){return vc(r,l,a)}}}function Sc(e){const t={};let n=-1,r,o,l,i,a,s,c;const u=new Ai(e);for(;++n<u.length;){for(;n in t;)n=t[n];if(r=u.get(n),n&&r[1].type==="chunkFlow"&&u.get(n-1)[1].type==="listItemPrefix"&&(s=r[1]._tokenizer.events,l=0,l<s.length&&s[l][1].type==="lineEndingBlank"&&(l+=2),l<s.length&&s[l][1].type==="content"))for(;++l<s.length&&s[l][1].type!=="content";)s[l][1].type==="chunkText"&&(s[l][1]._isInFirstContentOfListItem=!0,l++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,Rc(u,n)),n=t[n],c=!0);else if(r[1]._container){for(l=n,o=void 0;l--;)if(i=u.get(l),i[1].type==="lineEnding"||i[1].type==="lineEndingBlank")i[0]==="enter"&&(o&&(u.get(o)[1].type="lineEndingBlank"),i[1].type="lineEnding",o=l);else if(!(i[1].type==="linePrefix"||i[1].type==="listItemIndent"))break;o&&(r[1].end={...u.get(o)[1].start},a=u.slice(o,n),a.unshift(r),u.splice(o,n-o+1,a))}}return Qt(e,0,Number.POSITIVE_INFINITY,u.slice(0)),!c}function Rc(e,t){const n=e.get(t)[1],r=e.get(t)[2];let o=t-1;const l=[];let i=n._tokenizer;i||(i=r.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(i._contentTypeTextTrailing=!0));const a=i.events,s=[],c={};let u,f,p=-1,h=n,g=0,m=0;const w=[m];for(;h;){for(;e.get(++o)[1]!==h;);l.push(o),h._tokenizer||(u=r.sliceStream(h),h.next||u.push(null),f&&i.defineSkip(h.start),h._isInFirstContentOfListItem&&(i._gfmTasklistFirstContentOfListItem=!0),i.write(u),h._isInFirstContentOfListItem&&(i._gfmTasklistFirstContentOfListItem=void 0)),f=h,h=h.next}for(h=n;++p<a.length;)a[p][0]==="exit"&&a[p-1][0]==="enter"&&a[p][1].type===a[p-1][1].type&&a[p][1].start.line!==a[p][1].end.line&&(m=p+1,w.push(m),h._tokenizer=void 0,h.previous=void 0,h=h.next);for(i.events=[],h?(h._tokenizer=void 0,h.previous=void 0):w.pop(),p=w.length;p--;){const y=a.slice(w[p],w[p+1]),v=l.pop();s.push([v,v+y.length-1]),e.splice(v,2,y)}for(s.reverse(),p=-1;++p<s.length;)c[g+s[p][0]]=g+s[p][1],g+=s[p][1]-s[p][0]-1;return c}function Pc(e){for(;!Sc(e););return e}const Wr=/[\0\t\n\r]/g;function Oc(){let e=1,t="",n=!0,r;return o;function o(l,i,a){const s=[];let c,u,f,p,h;for(l=t+(typeof l=="string"?l.toString():new TextDecoder(i||void 0).decode(l)),f=0,t="",n&&(l.charCodeAt(0)===65279&&f++,n=void 0);f<l.length;){if(Wr.lastIndex=f,c=Wr.exec(l),p=c&&c.index!==void 0?c.index:l.length,h=l.charCodeAt(p),!c){t=l.slice(f);break}if(h===10&&f===p&&r)s.push(-3),r=void 0;else switch(r&&(s.push(-5),r=void 0),f<p&&(s.push(l.slice(f,p)),e+=p-f),h){case 0:{s.push(65533),e++;break}case 9:{for(u=Math.ceil(e/4)*4,s.push(-2);e++<u;)s.push(-1);break}case 10:{s.push(-4),e=1;break}default:r=!0,e=1}f=p+1}return a&&(r&&s.push(-5),t&&s.push(t),s.push(null)),s}}const _l={}.hasOwnProperty;function Tc(e,t,n){return typeof t!="string"&&(n=t,t=void 0),Ic(n)(Pc(Ec(n).document().write(Oc()(e,t,!0))))}function Ic(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:l(jt),autolinkProtocol:M,autolinkEmail:M,atxHeading:l(Ze),blockQuote:l(Ce),characterEscape:M,characterReference:M,codeFenced:l(de),codeFencedFenceInfo:i,codeFencedFenceMeta:i,codeIndented:l(de,i),codeText:l(Ae,i),codeTextData:M,data:M,codeFlowValue:M,definition:l(Ke),definitionDestinationString:i,definitionLabelString:i,definitionTitleString:i,emphasis:l(Qe),hardBreakEscape:l(et),hardBreakTrailing:l(et),htmlFlow:l(tt,i),htmlFlowData:M,htmlText:l(tt,i),htmlTextData:M,image:l(Q),label:i,link:l(jt),listItem:l(Ft),listItemValue:p,listOrdered:l(Ve,f),listUnordered:l(Ve),paragraph:l(Mt),reference:De,referenceString:i,resourceDestinationString:i,resourceTitleString:i,setextHeading:l(Ze),strong:l(Nt),thematicBreak:l(cn)},exit:{atxHeading:s(),atxHeadingSequence:I,autolink:s(),autolinkEmail:me,autolinkProtocol:ge,blockQuote:s(),characterEscapeValue:_,characterReferenceMarkerHexadecimal:ke,characterReferenceMarkerNumeric:ke,characterReferenceValue:J,characterReference:Le,codeFenced:s(w),codeFencedFence:m,codeFencedFenceInfo:h,codeFencedFenceMeta:g,codeFlowValue:_,codeIndented:s(y),codeText:s(Y),codeTextData:_,data:_,definition:s(),definitionDestinationString:S,definitionLabelString:v,definitionTitleString:x,emphasis:s(),hardBreakEscape:s(N),hardBreakTrailing:s(N),htmlFlow:s(R),htmlFlowData:_,htmlText:s(O),htmlTextData:_,image:s(he),label:je,labelText:ve,lineEnding:P,link:s(re),listItem:s(),listOrdered:s(),listUnordered:s(),paragraph:s(),referenceString:ue,resourceDestinationString:Ie,resourceTitleString:We,resource:oe,setextHeading:s($),setextHeadingLineSequence:T,setextHeadingText:F,strong:s(),thematicBreak:s()}};jl(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(b){let E={type:"root",children:[]};const D={stack:[E],tokenStack:[],config:t,enter:a,exit:c,buffer:i,resume:u,data:n},B=[];let G=-1;for(;++G<b.length;)if(b[G][1].type==="listOrdered"||b[G][1].type==="listUnordered")if(b[G][0]==="enter")B.push(G);else{const ae=B.pop();G=o(b,ae,G)}for(G=-1;++G<b.length;){const ae=t[b[G][0]];_l.call(ae,b[G][1].type)&&ae[b[G][1].type].call(Object.assign({sliceSerialize:b[G][2].sliceSerialize},D),b[G][1])}if(D.tokenStack.length>0){const ae=D.tokenStack[D.tokenStack.length-1];(ae[1]||Vr).call(D,void 0,ae[0])}for(E.position={start:ze(b.length>0?b[0][1].start:{line:1,column:1,offset:0}),end:ze(b.length>0?b[b.length-2][1].end:{line:1,column:1,offset:0})},G=-1;++G<t.transforms.length;)E=t.transforms[G](E)||E;return E}function o(b,E,D){let B=E-1,G=-1,ae=!1,Ee,ye,qe,Fe;for(;++B<=D;){const le=b[B];switch(le[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{le[0]==="enter"?G++:G--,Fe=void 0;break}case"lineEndingBlank":{le[0]==="enter"&&(Ee&&!Fe&&!G&&!qe&&(qe=B),Fe=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:Fe=void 0}if(!G&&le[0]==="enter"&&le[1].type==="listItemPrefix"||G===-1&&le[0]==="exit"&&(le[1].type==="listUnordered"||le[1].type==="listOrdered")){if(Ee){let Me=B;for(ye=void 0;Me--;){const be=b[Me];if(be[1].type==="lineEnding"||be[1].type==="lineEndingBlank"){if(be[0]==="exit")continue;ye&&(b[ye][1].type="lineEndingBlank",ae=!0),be[1].type="lineEnding",ye=Me}else if(!(be[1].type==="linePrefix"||be[1].type==="blockQuotePrefix"||be[1].type==="blockQuotePrefixWhitespace"||be[1].type==="blockQuoteMarker"||be[1].type==="listItemIndent"))break}qe&&(!ye||qe<ye)&&(Ee._spread=!0),Ee.end=Object.assign({},ye?b[ye][1].start:le[1].end),b.splice(ye||B,0,["exit",Ee,le[2]]),B++,D++}if(le[1].type==="listItemPrefix"){const Me={type:"listItem",_spread:!1,start:Object.assign({},le[1].start),end:void 0};Ee=Me,b.splice(B,0,["enter",Me,le[2]]),B++,D++,qe=void 0,Fe=!0}}}return b[E][1]._spread=ae,D}function l(b,E){return D;function D(B){a.call(this,b(B),B),E&&E.call(this,B)}}function i(){this.stack.push({type:"fragment",children:[]})}function a(b,E,D){this.stack[this.stack.length-1].children.push(b),this.stack.push(b),this.tokenStack.push([E,D||void 0]),b.position={start:ze(E.start),end:void 0}}function s(b){return E;function E(D){b&&b.call(this,D),c.call(this,D)}}function c(b,E){const D=this.stack.pop(),B=this.tokenStack.pop();if(B)B[0].type!==b.type&&(E?E.call(this,b,B[0]):(B[1]||Vr).call(this,b,B[0]));else throw new Error("Cannot close `"+b.type+"` ("+Et({start:b.start,end:b.end})+"): it’s not open");D.position.end=ze(b.end)}function u(){return $i(this.stack.pop())}function f(){this.data.expectingFirstListItemValue=!0}function p(b){if(this.data.expectingFirstListItemValue){const E=this.stack[this.stack.length-2];E.start=Number.parseInt(this.sliceSerialize(b),10),this.data.expectingFirstListItemValue=void 0}}function h(){const b=this.resume(),E=this.stack[this.stack.length-1];E.lang=b}function g(){const b=this.resume(),E=this.stack[this.stack.length-1];E.meta=b}function m(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function w(){const b=this.resume(),E=this.stack[this.stack.length-1];E.value=b.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function y(){const b=this.resume(),E=this.stack[this.stack.length-1];E.value=b.replace(/(\r?\n|\r)$/g,"")}function v(b){const E=this.resume(),D=this.stack[this.stack.length-1];D.label=E,D.identifier=gn(this.sliceSerialize(b)).toLowerCase()}function x(){const b=this.resume(),E=this.stack[this.stack.length-1];E.title=b}function S(){const b=this.resume(),E=this.stack[this.stack.length-1];E.url=b}function I(b){const E=this.stack[this.stack.length-1];if(!E.depth){const D=this.sliceSerialize(b).length;E.depth=D}}function F(){this.data.setextHeadingSlurpLineEnding=!0}function T(b){const E=this.stack[this.stack.length-1];E.depth=this.sliceSerialize(b).codePointAt(0)===61?1:2}function $(){this.data.setextHeadingSlurpLineEnding=void 0}function M(b){const D=this.stack[this.stack.length-1].children;let B=D[D.length-1];(!B||B.type!=="text")&&(B=Ht(),B.position={start:ze(b.start),end:void 0},D.push(B)),this.stack.push(B)}function _(b){const E=this.stack.pop();E.value+=this.sliceSerialize(b),E.position.end=ze(b.end)}function P(b){const E=this.stack[this.stack.length-1];if(this.data.atHardBreak){const D=E.children[E.children.length-1];D.position.end=ze(b.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(E.type)&&(M.call(this,b),_.call(this,b))}function N(){this.data.atHardBreak=!0}function R(){const b=this.resume(),E=this.stack[this.stack.length-1];E.value=b}function O(){const b=this.resume(),E=this.stack[this.stack.length-1];E.value=b}function Y(){const b=this.resume(),E=this.stack[this.stack.length-1];E.value=b}function re(){const b=this.stack[this.stack.length-1];if(this.data.inReference){const E=this.data.referenceType||"shortcut";b.type+="Reference",b.referenceType=E,delete b.url,delete b.title}else delete b.identifier,delete b.label;this.data.referenceType=void 0}function he(){const b=this.stack[this.stack.length-1];if(this.data.inReference){const E=this.data.referenceType||"shortcut";b.type+="Reference",b.referenceType=E,delete b.url,delete b.title}else delete b.identifier,delete b.label;this.data.referenceType=void 0}function ve(b){const E=this.sliceSerialize(b),D=this.stack[this.stack.length-2];D.label=_i(E),D.identifier=gn(E).toLowerCase()}function je(){const b=this.stack[this.stack.length-1],E=this.resume(),D=this.stack[this.stack.length-1];if(this.data.inReference=!0,D.type==="link"){const B=b.children;D.children=B}else D.alt=E}function Ie(){const b=this.resume(),E=this.stack[this.stack.length-1];E.url=b}function We(){const b=this.resume(),E=this.stack[this.stack.length-1];E.title=b}function oe(){this.data.inReference=void 0}function De(){this.data.referenceType="collapsed"}function ue(b){const E=this.resume(),D=this.stack[this.stack.length-1];D.label=E,D.identifier=gn(this.sliceSerialize(b)).toLowerCase(),this.data.referenceType="full"}function ke(b){this.data.characterReferenceType=b.type}function J(b){const E=this.sliceSerialize(b),D=this.data.characterReferenceType;let B;D?(B=Zs(E,D==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):B=ji(E);const G=this.stack[this.stack.length-1];G.value+=B}function Le(b){const E=this.stack.pop();E.position.end=ze(b.end)}function ge(b){_.call(this,b);const E=this.stack[this.stack.length-1];E.url=this.sliceSerialize(b)}function me(b){_.call(this,b);const E=this.stack[this.stack.length-1];E.url="mailto:"+this.sliceSerialize(b)}function Ce(){return{type:"blockquote",children:[]}}function de(){return{type:"code",lang:null,meta:null,value:""}}function Ae(){return{type:"inlineCode",value:""}}function Ke(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function Qe(){return{type:"emphasis",children:[]}}function Ze(){return{type:"heading",depth:0,children:[]}}function et(){return{type:"break"}}function tt(){return{type:"html",value:""}}function Q(){return{type:"image",title:null,url:"",alt:null}}function jt(){return{type:"link",title:null,url:"",children:[]}}function Ve(b){return{type:"list",ordered:b.type==="listOrdered",start:null,spread:b._spread,children:[]}}function Ft(b){return{type:"listItem",spread:b._spread,checked:null,children:[]}}function Mt(){return{type:"paragraph",children:[]}}function Nt(){return{type:"strong",children:[]}}function Ht(){return{type:"text",value:""}}function cn(){return{type:"thematicBreak"}}}function ze(e){return{line:e.line,column:e.column,offset:e.offset}}function jl(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?jl(e,r):Dc(e,r)}}function Dc(e,t){let n;for(n in t)if(_l.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function Vr(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+Et({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+Et({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+Et({start:t.start,end:t.end})+") is still open")}function Lc(e){const t=this;t.parser=n;function n(r){return Tc(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function Ac(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function $c(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function _c(e,t){const n=t.value?t.value+`
`:"",r={};t.lang&&(r.className=["language-"+t.lang]);let o={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(o.data={meta:t.meta}),e.patch(t,o),o=e.applyData(t,o),o={type:"element",tagName:"pre",properties:{},children:[o]},e.patch(t,o),o}function jc(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Fc(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Mc(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),o=ut(r.toLowerCase()),l=e.footnoteOrder.indexOf(r);let i,a=e.footnoteCounts.get(r);a===void 0?(a=0,e.footnoteOrder.push(r),i=e.footnoteOrder.length):i=l+1,a+=1,e.footnoteCounts.set(r,a);const s={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+o,id:n+"fnref-"+o+(a>1?"-"+a:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(i)}]};e.patch(t,s);const c={type:"element",tagName:"sup",properties:{},children:[s]};return e.patch(t,c),e.applyData(t,c)}function Nc(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Hc(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function Fl(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const o=e.all(t),l=o[0];l&&l.type==="text"?l.value="["+l.value:o.unshift({type:"text",value:"["});const i=o[o.length-1];return i&&i.type==="text"?i.value+=r:o.push({type:"text",value:r}),o}function zc(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return Fl(e,t);const o={src:ut(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(o.title=r.title);const l={type:"element",tagName:"img",properties:o,children:[]};return e.patch(t,l),e.applyData(t,l)}function Bc(e,t){const n={src:ut(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function Uc(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function Wc(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return Fl(e,t);const o={href:ut(r.url||"")};r.title!==null&&r.title!==void 0&&(o.title=r.title);const l={type:"element",tagName:"a",properties:o,children:e.all(t)};return e.patch(t,l),e.applyData(t,l)}function Vc(e,t){const n={href:ut(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function qc(e,t,n){const r=e.all(t),o=n?Gc(n):Ml(t),l={},i=[];if(typeof t.checked=="boolean"){const u=r[0];let f;u&&u.type==="element"&&u.tagName==="p"?f=u:(f={type:"element",tagName:"p",properties:{},children:[]},r.unshift(f)),f.children.length>0&&f.children.unshift({type:"text",value:" "}),f.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),l.className=["task-list-item"]}let a=-1;for(;++a<r.length;){const u=r[a];(o||a!==0||u.type!=="element"||u.tagName!=="p")&&i.push({type:"text",value:`
`}),u.type==="element"&&u.tagName==="p"&&!o?i.push(...u.children):i.push(u)}const s=r[r.length-1];s&&(o||s.type!=="element"||s.tagName!=="p")&&i.push({type:"text",value:`
`});const c={type:"element",tagName:"li",properties:l,children:i};return e.patch(t,c),e.applyData(t,c)}function Gc(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=Ml(n[r])}return t}function Ml(e){const t=e.spread;return t??e.children.length>1}function Xc(e,t){const n={},r=e.all(t);let o=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++o<r.length;){const i=r[o];if(i.type==="element"&&i.tagName==="li"&&i.properties&&Array.isArray(i.properties.className)&&i.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const l={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,l),e.applyData(t,l)}function Yc(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Jc(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function Kc(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Qc(e,t){const n=e.all(t),r=n.shift(),o=[];if(r){const i={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],i),o.push(i)}if(n.length>0){const i={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},a=Zn(t.children[1]),s=Pl(t.children[t.children.length-1]);a&&s&&(i.position={start:a,end:s}),o.push(i)}const l={type:"element",tagName:"table",properties:{},children:e.wrap(o,!0)};return e.patch(t,l),e.applyData(t,l)}function Zc(e,t,n){const r=n?n.children:void 0,l=(r?r.indexOf(t):1)===0?"th":"td",i=n&&n.type==="table"?n.align:void 0,a=i?i.length:t.children.length;let s=-1;const c=[];for(;++s<a;){const f=t.children[s],p={},h=i?i[s]:void 0;h&&(p.align=h);let g={type:"element",tagName:l,properties:p,children:[]};f&&(g.children=e.all(f),e.patch(f,g),g=e.applyData(f,g)),c.push(g)}const u={type:"element",tagName:"tr",properties:{},children:e.wrap(c,!0)};return e.patch(t,u),e.applyData(t,u)}function eu(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const qr=9,Gr=32;function tu(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),o=0;const l=[];for(;r;)l.push(Xr(t.slice(o,r.index),o>0,!0),r[0]),o=r.index+r[0].length,r=n.exec(t);return l.push(Xr(t.slice(o),o>0,!1)),l.join("")}function Xr(e,t,n){let r=0,o=e.length;if(t){let l=e.codePointAt(r);for(;l===qr||l===Gr;)r++,l=e.codePointAt(r)}if(n){let l=e.codePointAt(o-1);for(;l===qr||l===Gr;)o--,l=e.codePointAt(o-1)}return o>r?e.slice(r,o):""}function nu(e,t){const n={type:"text",value:tu(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function ru(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const ou={blockquote:Ac,break:$c,code:_c,delete:jc,emphasis:Fc,footnoteReference:Mc,heading:Nc,html:Hc,imageReference:zc,image:Bc,inlineCode:Uc,linkReference:Wc,link:Vc,listItem:qc,list:Xc,paragraph:Yc,root:Jc,strong:Kc,table:Qc,tableCell:eu,tableRow:Zc,text:nu,thematicBreak:ru,toml:Ut,yaml:Ut,definition:Ut,footnoteDefinition:Ut};function Ut(){}const Nl=-1,an=0,St=1,en=2,rr=3,or=4,lr=5,ir=6,Hl=7,zl=8,Yr=typeof self=="object"?self:globalThis,lu=(e,t)=>{const n=(o,l)=>(e.set(l,o),o),r=o=>{if(e.has(o))return e.get(o);const[l,i]=t[o];switch(l){case an:case Nl:return n(i,o);case St:{const a=n([],o);for(const s of i)a.push(r(s));return a}case en:{const a=n({},o);for(const[s,c]of i)a[r(s)]=r(c);return a}case rr:return n(new Date(i),o);case or:{const{source:a,flags:s}=i;return n(new RegExp(a,s),o)}case lr:{const a=n(new Map,o);for(const[s,c]of i)a.set(r(s),r(c));return a}case ir:{const a=n(new Set,o);for(const s of i)a.add(r(s));return a}case Hl:{const{name:a,message:s}=i;return n(new Yr[a](s),o)}case zl:return n(BigInt(i),o);case"BigInt":return n(Object(BigInt(i)),o);case"ArrayBuffer":return n(new Uint8Array(i).buffer,i);case"DataView":{const{buffer:a}=new Uint8Array(i);return n(new DataView(a),i)}}return n(new Yr[l](i),o)};return r},Jr=e=>lu(new Map,e)(0),it="",{toString:iu}={},{keys:au}=Object,kt=e=>{const t=typeof e;if(t!=="object"||!e)return[an,t];const n=iu.call(e).slice(8,-1);switch(n){case"Array":return[St,it];case"Object":return[en,it];case"Date":return[rr,it];case"RegExp":return[or,it];case"Map":return[lr,it];case"Set":return[ir,it];case"DataView":return[St,n]}return n.includes("Array")?[St,n]:n.includes("Error")?[Hl,n]:[en,n]},Wt=([e,t])=>e===an&&(t==="function"||t==="symbol"),su=(e,t,n,r)=>{const o=(i,a)=>{const s=r.push(i)-1;return n.set(a,s),s},l=i=>{if(n.has(i))return n.get(i);let[a,s]=kt(i);switch(a){case an:{let u=i;switch(s){case"bigint":a=zl,u=i.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+s);u=null;break;case"undefined":return o([Nl],i)}return o([a,u],i)}case St:{if(s){let p=i;return s==="DataView"?p=new Uint8Array(i.buffer):s==="ArrayBuffer"&&(p=new Uint8Array(i)),o([s,[...p]],i)}const u=[],f=o([a,u],i);for(const p of i)u.push(l(p));return f}case en:{if(s)switch(s){case"BigInt":return o([s,i.toString()],i);case"Boolean":case"Number":case"String":return o([s,i.valueOf()],i)}if(t&&"toJSON"in i)return l(i.toJSON());const u=[],f=o([a,u],i);for(const p of au(i))(e||!Wt(kt(i[p])))&&u.push([l(p),l(i[p])]);return f}case rr:return o([a,i.toISOString()],i);case or:{const{source:u,flags:f}=i;return o([a,{source:u,flags:f}],i)}case lr:{const u=[],f=o([a,u],i);for(const[p,h]of i)(e||!(Wt(kt(p))||Wt(kt(h))))&&u.push([l(p),l(h)]);return f}case ir:{const u=[],f=o([a,u],i);for(const p of i)(e||!Wt(kt(p)))&&u.push(l(p));return f}}const{message:c}=i;return o([a,{name:s,message:c}],i)};return l},Kr=(e,{json:t,lossy:n}={})=>{const r=[];return su(!(t||n),!!t,new Map,r)(e),r},tn=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?Jr(Kr(e,t)):structuredClone(e):(e,t)=>Jr(Kr(e,t));function cu(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function uu(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function du(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||cu,r=e.options.footnoteBackLabel||uu,o=e.options.footnoteLabel||"Footnotes",l=e.options.footnoteLabelTagName||"h2",i=e.options.footnoteLabelProperties||{className:["sr-only"]},a=[];let s=-1;for(;++s<e.footnoteOrder.length;){const c=e.footnoteById.get(e.footnoteOrder[s]);if(!c)continue;const u=e.all(c),f=String(c.identifier).toUpperCase(),p=ut(f.toLowerCase());let h=0;const g=[],m=e.footnoteCounts.get(f);for(;m!==void 0&&++h<=m;){g.length>0&&g.push({type:"text",value:" "});let v=typeof n=="string"?n:n(s,h);typeof v=="string"&&(v={type:"text",value:v}),g.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+p+(h>1?"-"+h:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(s,h),className:["data-footnote-backref"]},children:Array.isArray(v)?v:[v]})}const w=u[u.length-1];if(w&&w.type==="element"&&w.tagName==="p"){const v=w.children[w.children.length-1];v&&v.type==="text"?v.value+=" ":w.children.push({type:"text",value:" "}),w.children.push(...g)}else u.push(...g);const y={type:"element",tagName:"li",properties:{id:t+"fn-"+p},children:e.wrap(u,!0)};e.patch(c,y),a.push(y)}if(a.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:l,properties:{...tn(i),id:"footnote-label"},children:[{type:"text",value:o}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(a,!0)},{type:"text",value:`
`}]}}const Nn={}.hasOwnProperty,fu={};function pu(e,t){const n=t||fu,r=new Map,o=new Map,l=new Map,i={...ou,...n.handlers},a={all:c,applyData:gu,definitionById:r,footnoteById:o,footnoteCounts:l,footnoteOrder:[],handlers:i,one:s,options:n,patch:hu,wrap:yu};return tl(e,function(u){if(u.type==="definition"||u.type==="footnoteDefinition"){const f=u.type==="definition"?r:o,p=String(u.identifier).toUpperCase();f.has(p)||f.set(p,u)}}),a;function s(u,f){const p=u.type,h=a.handlers[p];if(Nn.call(a.handlers,p)&&h)return h(a,u,f);if(a.options.passThrough&&a.options.passThrough.includes(p)){if("children"in u){const{children:m,...w}=u,y=tn(w);return y.children=a.all(u),y}return tn(u)}return(a.options.unknownHandler||mu)(a,u,f)}function c(u){const f=[];if("children"in u){const p=u.children;let h=-1;for(;++h<p.length;){const g=a.one(p[h],u);if(g){if(h&&p[h-1].type==="break"&&(!Array.isArray(g)&&g.type==="text"&&(g.value=Qr(g.value)),!Array.isArray(g)&&g.type==="element")){const m=g.children[0];m&&m.type==="text"&&(m.value=Qr(m.value))}Array.isArray(g)?f.push(...g):f.push(g)}}}return f}}function hu(e,t){e.position&&(t.position=Ls(e))}function gu(e,t){let n=t;if(e&&e.data){const r=e.data.hName,o=e.data.hChildren,l=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const i="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:i}}n.type==="element"&&l&&Object.assign(n.properties,tn(l)),"children"in n&&n.children&&o!==null&&o!==void 0&&(n.children=o)}return n}function mu(e,t){const n=t.data||{},r="value"in t&&!(Nn.call(n,"hProperties")||Nn.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function yu(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function Qr(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function Zr(e,t){const n=pu(e,t),r=n.one(e,void 0),o=du(n),l=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return o&&l.children.push({type:"text",value:`
`},o),l}function bu(e,t){return e&&"run"in e?async function(n,r){const o=Zr(n,{file:r,...t});await e.run(o,r)}:function(n,r){return Zr(n,{file:r,...e||t})}}function eo(e){if(e)throw e}var Cn,to;function xu(){if(to)return Cn;to=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,o=function(c){return typeof Array.isArray=="function"?Array.isArray(c):t.call(c)==="[object Array]"},l=function(c){if(!c||t.call(c)!=="[object Object]")return!1;var u=e.call(c,"constructor"),f=c.constructor&&c.constructor.prototype&&e.call(c.constructor.prototype,"isPrototypeOf");if(c.constructor&&!u&&!f)return!1;var p;for(p in c);return typeof p>"u"||e.call(c,p)},i=function(c,u){n&&u.name==="__proto__"?n(c,u.name,{enumerable:!0,configurable:!0,value:u.newValue,writable:!0}):c[u.name]=u.newValue},a=function(c,u){if(u==="__proto__")if(e.call(c,u)){if(r)return r(c,u).value}else return;return c[u]};return Cn=function s(){var c,u,f,p,h,g,m=arguments[0],w=1,y=arguments.length,v=!1;for(typeof m=="boolean"&&(v=m,m=arguments[1]||{},w=2),(m==null||typeof m!="object"&&typeof m!="function")&&(m={});w<y;++w)if(c=arguments[w],c!=null)for(u in c)f=a(m,u),p=a(c,u),m!==p&&(v&&p&&(l(p)||(h=o(p)))?(h?(h=!1,g=f&&o(f)?f:[]):g=f&&l(f)?f:{},i(m,{name:u,newValue:s(v,g,p)})):typeof p<"u"&&i(m,{name:u,newValue:p}));return m},Cn}var wu=xu();const En=Qo(wu);function Hn(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function vu(){const e=[],t={run:n,use:r};return t;function n(...o){let l=-1;const i=o.pop();if(typeof i!="function")throw new TypeError("Expected function as last argument, not "+i);a(null,...o);function a(s,...c){const u=e[++l];let f=-1;if(s){i(s);return}for(;++f<o.length;)(c[f]===null||c[f]===void 0)&&(c[f]=o[f]);o=c,u?ku(u,a)(...c):i(null,...c)}}function r(o){if(typeof o!="function")throw new TypeError("Expected `middelware` to be a function, not "+o);return e.push(o),t}}function ku(e,t){let n;return r;function r(...i){const a=e.length>i.length;let s;a&&i.push(o);try{s=e.apply(this,i)}catch(c){const u=c;if(a&&n)throw u;return o(u)}a||(s&&s.then&&typeof s.then=="function"?s.then(l,o):s instanceof Error?o(s):l(s))}function o(i,...a){n||(n=!0,t(i,...a))}function l(i){o(null,i)}}const Re={basename:Cu,dirname:Eu,extname:Su,join:Ru,sep:"/"};function Cu(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');_t(e);let n=0,r=-1,o=e.length,l;if(t===void 0||t.length===0||t.length>e.length){for(;o--;)if(e.codePointAt(o)===47){if(l){n=o+1;break}}else r<0&&(l=!0,r=o+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let i=-1,a=t.length-1;for(;o--;)if(e.codePointAt(o)===47){if(l){n=o+1;break}}else i<0&&(l=!0,i=o+1),a>-1&&(e.codePointAt(o)===t.codePointAt(a--)?a<0&&(r=o):(a=-1,r=i));return n===r?r=i:r<0&&(r=e.length),e.slice(n,r)}function Eu(e){if(_t(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function Su(e){_t(e);let t=e.length,n=-1,r=0,o=-1,l=0,i;for(;t--;){const a=e.codePointAt(t);if(a===47){if(i){r=t+1;break}continue}n<0&&(i=!0,n=t+1),a===46?o<0?o=t:l!==1&&(l=1):o>-1&&(l=-1)}return o<0||n<0||l===0||l===1&&o===n-1&&o===r+1?"":e.slice(o,n)}function Ru(...e){let t=-1,n;for(;++t<e.length;)_t(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":Pu(n)}function Pu(e){_t(e);const t=e.codePointAt(0)===47;let n=Ou(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function Ou(e,t){let n="",r=0,o=-1,l=0,i=-1,a,s;for(;++i<=e.length;){if(i<e.length)a=e.codePointAt(i);else{if(a===47)break;a=47}if(a===47){if(!(o===i-1||l===1))if(o!==i-1&&l===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(s=n.lastIndexOf("/"),s!==n.length-1){s<0?(n="",r=0):(n=n.slice(0,s),r=n.length-1-n.lastIndexOf("/")),o=i,l=0;continue}}else if(n.length>0){n="",r=0,o=i,l=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(o+1,i):n=e.slice(o+1,i),r=i-o-1;o=i,l=0}else a===46&&l>-1?l++:l=-1}return n}function _t(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const Tu={cwd:Iu};function Iu(){return"/"}function zn(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function Du(e){if(typeof e=="string")e=new URL(e);else if(!zn(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return Lu(e)}function Lu(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const o=new TypeError("File URL path must not include encoded / characters");throw o.code="ERR_INVALID_FILE_URL_PATH",o}}return decodeURIComponent(t)}const Sn=["history","path","basename","stem","extname","dirname"];class Bl{constructor(t){let n;t?zn(t)?n={path:t}:typeof t=="string"||Au(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":Tu.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<Sn.length;){const l=Sn[r];l in n&&n[l]!==void 0&&n[l]!==null&&(this[l]=l==="history"?[...n[l]]:n[l])}let o;for(o in n)Sn.includes(o)||(this[o]=n[o])}get basename(){return typeof this.path=="string"?Re.basename(this.path):void 0}set basename(t){Pn(t,"basename"),Rn(t,"basename"),this.path=Re.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?Re.dirname(this.path):void 0}set dirname(t){no(this.basename,"dirname"),this.path=Re.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?Re.extname(this.path):void 0}set extname(t){if(Rn(t,"extname"),no(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=Re.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){zn(t)&&(t=Du(t)),Pn(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?Re.basename(this.path,this.extname):void 0}set stem(t){Pn(t,"stem"),Rn(t,"stem"),this.path=Re.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const o=this.message(t,n,r);throw o.fatal=!0,o}info(t,n,r){const o=this.message(t,n,r);return o.fatal=void 0,o}message(t,n,r){const o=new ne(t,n,r);return this.path&&(o.name=this.path+":"+o.name,o.file=this.path),o.fatal=!1,this.messages.push(o),o}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function Rn(e,t){if(e&&e.includes(Re.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+Re.sep+"`")}function Pn(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function no(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function Au(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const $u=function(e){const r=this.constructor.prototype,o=r[e],l=function(){return o.apply(l,arguments)};return Object.setPrototypeOf(l,r),l},_u={}.hasOwnProperty;class ar extends $u{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=vu()}copy(){const t=new ar;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(En(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(In("data",this.frozen),this.namespace[t]=n,this):_u.call(this.namespace,t)&&this.namespace[t]||void 0:t?(In("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const o=n.call(t,...r);typeof o=="function"&&this.transformers.use(o)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=Vt(t),r=this.parser||this.Parser;return On("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),On("process",this.parser||this.Parser),Tn("process",this.compiler||this.Compiler),n?o(void 0,n):new Promise(o);function o(l,i){const a=Vt(t),s=r.parse(a);r.run(s,a,function(u,f,p){if(u||!f||!p)return c(u);const h=f,g=r.stringify(h,p);Mu(g)?p.value=g:p.result=g,c(u,p)});function c(u,f){u||!f?i(u):l?l(f):n(void 0,f)}}}processSync(t){let n=!1,r;return this.freeze(),On("processSync",this.parser||this.Parser),Tn("processSync",this.compiler||this.Compiler),this.process(t,o),oo("processSync","process",n),r;function o(l,i){n=!0,eo(l),r=i}}run(t,n,r){ro(t),this.freeze();const o=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?l(void 0,r):new Promise(l);function l(i,a){const s=Vt(n);o.run(t,s,c);function c(u,f,p){const h=f||t;u?a(u):i?i(h):r(void 0,h,p)}}}runSync(t,n){let r=!1,o;return this.run(t,n,l),oo("runSync","run",r),o;function l(i,a){eo(i),o=a,r=!0}}stringify(t,n){this.freeze();const r=Vt(n),o=this.compiler||this.Compiler;return Tn("stringify",o),ro(t),o(t,r)}use(t,...n){const r=this.attachers,o=this.namespace;if(In("use",this.frozen),t!=null)if(typeof t=="function")s(t,n);else if(typeof t=="object")Array.isArray(t)?a(t):i(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function l(c){if(typeof c=="function")s(c,[]);else if(typeof c=="object")if(Array.isArray(c)){const[u,...f]=c;s(u,f)}else i(c);else throw new TypeError("Expected usable value, not `"+c+"`")}function i(c){if(!("plugins"in c)&&!("settings"in c))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");a(c.plugins),c.settings&&(o.settings=En(!0,o.settings,c.settings))}function a(c){let u=-1;if(c!=null)if(Array.isArray(c))for(;++u<c.length;){const f=c[u];l(f)}else throw new TypeError("Expected a list of plugins, not `"+c+"`")}function s(c,u){let f=-1,p=-1;for(;++f<r.length;)if(r[f][0]===c){p=f;break}if(p===-1)r.push([c,...u]);else if(u.length>0){let[h,...g]=u;const m=r[p][1];Hn(m)&&Hn(h)&&(h=En(!0,m,h)),r[p]=[c,h,...g]}}}}const ju=new ar().freeze();function On(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function Tn(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function In(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function ro(e){if(!Hn(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function oo(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function Vt(e){return Fu(e)?e:new Bl(e)}function Fu(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function Mu(e){return typeof e=="string"||Nu(e)}function Nu(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const Hu="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",lo=[],io={allowDangerousHtml:!0},zu=/^(https?|ircs?|mailto|xmpp)$/i,Bu=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function yf(e){const t=Uu(e),n=Wu(e);return Vu(t.runSync(t.parse(n),n),e)}function Uu(e){const t=e.rehypePlugins||lo,n=e.remarkPlugins||lo,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...io}:io;return ju().use(Lc).use(n).use(bu,r).use(t)}function Wu(e){const t=e.children||"",n=new Bl;return typeof t=="string"&&(n.value=t),n}function Vu(e,t){const n=t.allowedElements,r=t.allowElement,o=t.components,l=t.disallowedElements,i=t.skipHtml,a=t.unwrapDisallowed,s=t.urlTransform||qu;for(const u of Bu)Object.hasOwn(t,u.from)&&Fi("Unexpected `"+u.from+"` prop, "+(u.to?"use `"+u.to+"` instead":"remove it")+" (see <"+Hu+"#"+u.id+"> for more info)");return tl(e,c),Fs(e,{Fragment:yn.Fragment,components:o,ignoreInvalidStyle:!0,jsx:yn.jsx,jsxs:yn.jsxs,passKeys:!0,passNode:!0});function c(u,f,p){if(u.type==="raw"&&p&&typeof f=="number")return i?p.children.splice(f,1):p.children[f]={type:"text",value:u.value},f;if(u.type==="element"){let h;for(h in kn)if(Object.hasOwn(kn,h)&&Object.hasOwn(u.properties,h)){const g=u.properties[h],m=kn[h];(m===null||m.includes(u.tagName))&&(u.properties[h]=s(String(g||""),h,u))}}if(u.type==="element"){let h=n?!n.includes(u.tagName):l?l.includes(u.tagName):!1;if(!h&&r&&typeof f=="number"&&(h=!r(u,f,p)),h&&p&&typeof f=="number")return a&&u.children?p.children.splice(f,1,...u.children):p.children.splice(f,1),f}}}function qu(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),o=e.indexOf("/");return t===-1||o!==-1&&t>o||n!==-1&&t>n||r!==-1&&t>r||zu.test(e.slice(0,t))?e:""}var nn=function(){return nn=Object.assign||function(t){for(var n,r=1,o=arguments.length;r<o;r++){n=arguments[r];for(var l in n)Object.prototype.hasOwnProperty.call(n,l)&&(t[l]=n[l])}return t},nn.apply(this,arguments)};function Gu(e,t,n){for(var r=0,o=t.length,l;r<o;r++)(l||!(r in t))&&(l||(l=Array.prototype.slice.call(t,0,r)),l[r]=t[r]);return e.concat(l||Array.prototype.slice.call(t))}function W(e,t){return Object.defineProperty?Object.defineProperty(e,"raw",{value:t}):e.raw=t,e}function Xu(e){var t=Object.create(null);return function(n){return t[n]===void 0&&(t[n]=e(n)),t[n]}}var Yu=/^((children|dangerouslySetInnerHTML|key|ref|autoFocus|defaultValue|defaultChecked|innerHTML|suppressContentEditableWarning|suppressHydrationWarning|valueLink|abbr|accept|acceptCharset|accessKey|action|allow|allowUserMedia|allowPaymentRequest|allowFullScreen|allowTransparency|alt|async|autoComplete|autoPlay|capture|cellPadding|cellSpacing|challenge|charSet|checked|cite|classID|className|cols|colSpan|content|contentEditable|contextMenu|controls|controlsList|coords|crossOrigin|data|dateTime|decoding|default|defer|dir|disabled|disablePictureInPicture|disableRemotePlayback|download|draggable|encType|enterKeyHint|form|formAction|formEncType|formMethod|formNoValidate|formTarget|frameBorder|headers|height|hidden|high|href|hrefLang|htmlFor|httpEquiv|id|inputMode|integrity|is|keyParams|keyType|kind|label|lang|list|loading|loop|low|marginHeight|marginWidth|max|maxLength|media|mediaGroup|method|min|minLength|multiple|muted|name|nonce|noValidate|open|optimum|pattern|placeholder|playsInline|poster|preload|profile|radioGroup|readOnly|referrerPolicy|rel|required|reversed|role|rows|rowSpan|sandbox|scope|scoped|scrolling|seamless|selected|shape|size|sizes|slot|span|spellCheck|src|srcDoc|srcLang|srcSet|start|step|style|summary|tabIndex|target|title|translate|type|useMap|value|width|wmode|wrap|about|datatype|inlist|prefix|property|resource|typeof|vocab|autoCapitalize|autoCorrect|autoSave|color|incremental|fallback|inert|itemProp|itemScope|itemType|itemID|itemRef|on|option|results|security|unselectable|accentHeight|accumulate|additive|alignmentBaseline|allowReorder|alphabetic|amplitude|arabicForm|ascent|attributeName|attributeType|autoReverse|azimuth|baseFrequency|baselineShift|baseProfile|bbox|begin|bias|by|calcMode|capHeight|clip|clipPathUnits|clipPath|clipRule|colorInterpolation|colorInterpolationFilters|colorProfile|colorRendering|contentScriptType|contentStyleType|cursor|cx|cy|d|decelerate|descent|diffuseConstant|direction|display|divisor|dominantBaseline|dur|dx|dy|edgeMode|elevation|enableBackground|end|exponent|externalResourcesRequired|fill|fillOpacity|fillRule|filter|filterRes|filterUnits|floodColor|floodOpacity|focusable|fontFamily|fontSize|fontSizeAdjust|fontStretch|fontStyle|fontVariant|fontWeight|format|from|fr|fx|fy|g1|g2|glyphName|glyphOrientationHorizontal|glyphOrientationVertical|glyphRef|gradientTransform|gradientUnits|hanging|horizAdvX|horizOriginX|ideographic|imageRendering|in|in2|intercept|k|k1|k2|k3|k4|kernelMatrix|kernelUnitLength|kerning|keyPoints|keySplines|keyTimes|lengthAdjust|letterSpacing|lightingColor|limitingConeAngle|local|markerEnd|markerMid|markerStart|markerHeight|markerUnits|markerWidth|mask|maskContentUnits|maskUnits|mathematical|mode|numOctaves|offset|opacity|operator|order|orient|orientation|origin|overflow|overlinePosition|overlineThickness|panose1|paintOrder|pathLength|patternContentUnits|patternTransform|patternUnits|pointerEvents|points|pointsAtX|pointsAtY|pointsAtZ|preserveAlpha|preserveAspectRatio|primitiveUnits|r|radius|refX|refY|renderingIntent|repeatCount|repeatDur|requiredExtensions|requiredFeatures|restart|result|rotate|rx|ry|scale|seed|shapeRendering|slope|spacing|specularConstant|specularExponent|speed|spreadMethod|startOffset|stdDeviation|stemh|stemv|stitchTiles|stopColor|stopOpacity|strikethroughPosition|strikethroughThickness|string|stroke|strokeDasharray|strokeDashoffset|strokeLinecap|strokeLinejoin|strokeMiterlimit|strokeOpacity|strokeWidth|surfaceScale|systemLanguage|tableValues|targetX|targetY|textAnchor|textDecoration|textRendering|textLength|to|transform|u1|u2|underlinePosition|underlineThickness|unicode|unicodeBidi|unicodeRange|unitsPerEm|vAlphabetic|vHanging|vIdeographic|vMathematical|values|vectorEffect|version|vertAdvY|vertOriginX|vertOriginY|viewBox|viewTarget|visibility|widths|wordSpacing|writingMode|x|xHeight|x1|x2|xChannelSelector|xlinkActuate|xlinkArcrole|xlinkHref|xlinkRole|xlinkShow|xlinkTitle|xlinkType|xmlBase|xmlns|xmlnsXlink|xmlLang|xmlSpace|y|y1|y2|yChannelSelector|z|zoomAndPan|for|class|autofocus)|(([Dd][Aa][Tt][Aa]|[Aa][Rr][Ii][Aa]|x)-.*))$/,sn=Xu(function(e){return Yu.test(e)||e.charCodeAt(0)===111&&e.charCodeAt(1)===110&&e.charCodeAt(2)<91}),Ul="awesomegrid",se=["xs","sm","md","lg","xl"],Ju={media:null,mediaQuery:"only screen",columns:{xs:4,sm:8,md:8,lg:12,xl:12},gutterWidth:{xs:1,sm:1,md:1.5,lg:1.5,xl:1.5},paddingWidth:{xs:1,sm:1,md:1.5,lg:1.5,xl:1.5},container:{xs:"full",sm:"full",md:"full",lg:90,xl:90},breakpoints:{xs:1,sm:48,md:64,lg:90,xl:120}},qt=[],Ku=function(e){return e!=null&&e.theme?JSON.stringify(e.theme[Ul]||{}):{}},Qu=function(e){var t={};e!=null&&e.theme&&(t=e.theme[Ul]||{});var n=nn(nn({},Ju),t);return n.media=Object.keys(n.breakpoints).reduce(function(r,o){var l=n.breakpoints[o];return r[o]=Zu([n.mediaQuery,l>=0&&"(min-width: ".concat(l,"rem)")].filter(Boolean).join(" and ")),r},{}),n};function z(e){var t=Ku(e);if(qt[0]===t)return qt[1];var n=Qu(e);return qt[0]=t,qt[1]=n,n}function Zu(e){return function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];return U(ao||(ao=W([`
    @media `,` {
      `,`
    }
  `],[`
    @media `,` {
      `,`
    }
  `])),e,U.apply(null,Gu([],t)))}}var ao,bf=H("div").withConfig({shouldForwardProp:function(e){return sn(e)}})(ho||(ho=W([`
  margin-right: auto;
  margin-left: auto;
  max-width: 100%;
  width: 100%;
  box-sizing: border-box;

  `,`

  `,`

  `,`
`],[`
  margin-right: auto;
  margin-left: auto;
  max-width: 100%;
  width: 100%;
  box-sizing: border-box;

  `,`

  `,`

  `,`
`])),function(e){return U(co||(co=W([`
    `,`
  `],[`
    `,`
  `])),se.map(function(t){return z(e).container[t]&&z(e).media[t](so||(so=W([`
      padding-left: `,`rem;
      padding-right: `,`rem;
    `],[`
      padding-left: `,`rem;
      padding-right: `,`rem;
    `])),z(e).paddingWidth[t],z(e).paddingWidth[t])}))},function(e){return!e.fluid&&U(fo||(fo=W([`
      `,`
    `],[`
      `,`
    `])),se.map(function(t){return z(e).container[t]&&z(e).media[t](uo||(uo=W([`
      `,`
    `],[`
      `,`
    `])),typeof z(e).container[t]=="number"?"max-width: ".concat(z(e).container[t],"rem;"):"width: 100%;")}))},function(e){var t=e.debug;return t&&U(po||(po=W([`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `],[`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `])))}),so,co,uo,fo,po,ho,xf=H.div.withConfig({shouldForwardProp:function(e){return sn(e)}})(Eo||(Eo=W([`
  box-sizing: border-box;
  display: flex;
  flex: 1 1 auto;
  flex-wrap: wrap;

  `,`

  `,`

  `,`
  
  `,`

  `,`
`],[`
  box-sizing: border-box;
  display: flex;
  flex: 1 1 auto;
  flex-wrap: wrap;

  `,`

  `,`

  `,`
  
  `,`

  `,`
`])),function(e){return U(mo||(mo=W([`
    `,`
  `],[`
    `,`
  `])),se.map(function(t){return z(e).container[t]&&z(e).media[t](go||(go=W([`
      margin-left: -`,`rem;
      margin-right: -`,`rem;
    `],[`
      margin-left: -`,`rem;
      margin-right: -`,`rem;
    `])),z(e).gutterWidth[t]/2,z(e).gutterWidth[t]/2)}))},function(e){return e.reverse&&U(bo||(bo=W([`
      `,`
    `],[`
      `,`
    `])),Array.isArray(e.reverse)?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](yo||(yo=W([`
         `,`;
        
      `],[`
         `,`;
        
      `])),Array.isArray(e.reverse)&&e.reverse.indexOf(t)!==-1?`
             flex-direction: row-reverse;
             flex-wrap: wrap-reverse;
             `:`
                 flex-direction: row;
                 flex-wrap: wrap;
               `)}):`
            flex-direction: row-reverse;
            flex-wrap: wrap-reverse;
          `)},function(e){return e.align&&U(wo||(wo=W([`
      `,`
    `],[`
      `,`
    `])),typeof e.align=="object"?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](xo||(xo=W(["",""],["",""])),e.align[t]&&"align-items: ".concat(e.align[t]))}):"align-items: ".concat(e.align,";"))},function(e){return e.justify&&U(ko||(ko=W([`
      `,`
    `],[`
      `,`
    `])),typeof e.justify=="object"?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](vo||(vo=W(["",""],["",""])),e.justify[t]&&"justify-content: ".concat(e.justify[t]))}):"justify-content: ".concat(e.justify,";"))},function(e){var t=e.debug;return t&&U(Co||(Co=W([`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `],[`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `])))}),go,mo,yo,bo,xo,wo,vo,ko,Co,Eo,wf=H.div.withConfig({shouldForwardProp:function(e){return sn(e)}})(Ho||(Ho=W([`
  box-sizing: border-box;
  flex: 1 0 auto;
  max-width: 100%;
  display: flex;
  flex-direction: column;

  `,`

  `,`

  `,`

  `,`

  `,`

  `,`
  
  `,`
  
  `,`
`],[`
  box-sizing: border-box;
  flex: 1 0 auto;
  max-width: 100%;
  display: flex;
  flex-direction: column;

  `,`

  `,`

  `,`

  `,`

  `,`

  `,`
  
  `,`
  
  `,`
`])),function(e){return!e.noGutter&&U(Ro||(Ro=W([`
      `,`
    `],[`
      `,`
    `])),se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](So||(So=W([`
      padding-right: `,`rem;
      padding-left: `,`rem;
    `],[`
      padding-right: `,`rem;
      padding-left: `,`rem;
    `])),z(e).gutterWidth[t]/2,z(e).gutterWidth[t]/2)}))},function(e){return U(Oo||(Oo=W([`
    `,`
  `],[`
    `,`
  `])),se.map(function(t){return e[t]&&z(e).breakpoints[t]&&z(e).media[t](Po||(Po=W([`
      flex: 1 1 `,`%;
      max-width: `,`%;
    `],[`
      flex: 1 1 `,`%;
      max-width: `,`%;
    `])),+e[t]/z(e).columns[t]*100,+e[t]/z(e).columns[t]*100)}))},function(e){return e.offset&&U(Io||(Io=W([`
      `,`
    `],[`
      `,`
    `])),se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](To||(To=W([`
    `,`;
    `],[`
    `,`;
    `])),typeof e.offset=="object"?e.offset[t]!==void 0&&"margin-left: ".concat(e.offset[t]>0?e.offset[t]/z(e).columns[t]*100:0,"%"):"margin-left: ".concat(e.offset/z(e).columns.xs*100,"%"))}))},function(e){return e.order!==void 0&&U(Lo||(Lo=W([`
      `,`
    `],[`
      `,`
    `])),se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](Do||(Do=W([`
    `,`;
    `],[`
    `,`;
    `])),typeof e.order=="object"?e.order[t]!==void 0&&"order: ".concat(e.order[t]):"order: ".concat(e.order))}))},function(e){return e.reverse&&U($o||($o=W([`
      `,`
    `],[`
      `,`
    `])),Array.isArray(e.reverse)?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](Ao||(Ao=W([`
        flex-direction: `,`;
      `],[`
        flex-direction: `,`;
      `])),Array.isArray(e.reverse)&&e.reverse.indexOf(t)!==-1?"column-reverse":"column")}):"flex-direction: column-reverse;")},function(e){return e.align&&U(jo||(jo=W([`
      `,`
    `],[`
      `,`
    `])),typeof e.align=="object"?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](_o||(_o=W(["",""],["",""])),e.align[t]&&"align-items: ".concat(e.align[t]))}):"align-items: ".concat(e.align,";"))},function(e){return e.justify&&U(Mo||(Mo=W([`
      `,`
    `],[`
      `,`
    `])),typeof e.justify=="object"?se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](Fo||(Fo=W(["",""],["",""])),e.justify[t]&&"justify-content: ".concat(e.justify[t]))}):"justify-content: ".concat(e.justify,";"))},function(e){var t=e.debug;return t&&U(No||(No=W([`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `],[`
      background-color: #5901ad40;
      outline: #fff solid 1px;
    `])))}),So,Ro,Po,Oo,To,Io,Do,Lo,Ao,$o,_o,jo,Fo,Mo,No,Ho;H.div.withConfig({shouldForwardProp:function(e){return sn(e)}})(Uo||(Uo=W([`
  z-index: 10;
  position: fixed;
  font-size: 1.5rem;
  font-weight: bold;
  right: 10px;
  bottom: 10px;
  width: 50px;
  height: 30px;
  background-color: #5901ad40;
  display: flex;
  border-radius: 5px;
  justify-content: center;
  align-items: center;
  `,`
`],[`
  z-index: 10;
  position: fixed;
  font-size: 1.5rem;
  font-weight: bold;
  right: 10px;
  bottom: 10px;
  width: 50px;
  height: 30px;
  background-color: #5901ad40;
  display: flex;
  border-radius: 5px;
  justify-content: center;
  align-items: center;
  `,`
`])),function(e){return U(Bo||(Bo=W([`
    `,`
  `],[`
    `,`
  `])),se.map(function(t){return z(e).breakpoints[t]&&z(e).media[t](zo||(zo=W([`
      &::before {
        content: '`,`'
      }
    `],[`
      &::before {
        content: '`,`'
      }
    `])),t)}))});var zo,Bo,Uo,Ue;function st(e,t){return e[t]}function ed(e=[],t,n=0){return[...e.slice(0,n),t,...e.slice(n)]}function td(e=[],t,n="id"){const r=e.slice(),o=st(t,n);return o?r.splice(r.findIndex(l=>st(l,n)===o),1):r.splice(r.findIndex(l=>l===t),1),r}function Wo(e){return e.map((t,n)=>{const r=Object.assign(Object.assign({},t),{sortable:t.sortable||!!t.sortFunction||void 0});return t.id||(r.id=n+1),r})}function Rt(e,t){return Math.ceil(e/t)}function Dn(e,t){return Math.min(e,t)}(function(e){e.ASC="asc",e.DESC="desc"})(Ue||(Ue={}));const ee=()=>null;function Wl(e,t=[],n=[]){let r={},o=[...n];return t.length&&t.forEach(l=>{if(!l.when||typeof l.when!="function")throw new Error('"when" must be defined in the conditional style object and must be function');l.when(e)&&(r=l.style||{},l.classNames&&(o=[...o,...l.classNames]),typeof l.style=="function"&&(r=l.style(e)||{}))}),{conditionalStyle:r,classNames:o.join(" ")}}function Kt(e,t=[],n="id"){const r=st(e,n);return r?t.some(o=>st(o,n)===r):t.some(o=>o===e)}function Gt(e,t){return t?e.findIndex(n=>Pt(n.id,t)):-1}function Pt(e,t){return e==t}function nd(e,t){const n=!e.toggleOnSelectedRowsChange;switch(t.type){case"SELECT_ALL_ROWS":{const{keyField:r,rows:o,rowCount:l,mergeSelections:i}=t,a=!e.allSelected,s=!e.toggleOnSelectedRowsChange;if(i){const c=a?[...e.selectedRows,...o.filter(u=>!Kt(u,e.selectedRows,r))]:e.selectedRows.filter(u=>!Kt(u,o,r));return Object.assign(Object.assign({},e),{allSelected:a,selectedCount:c.length,selectedRows:c,toggleOnSelectedRowsChange:s})}return Object.assign(Object.assign({},e),{allSelected:a,selectedCount:a?l:0,selectedRows:a?o:[],toggleOnSelectedRowsChange:s})}case"SELECT_SINGLE_ROW":{const{keyField:r,row:o,isSelected:l,rowCount:i,singleSelect:a}=t;return a?l?Object.assign(Object.assign({},e),{selectedCount:0,allSelected:!1,selectedRows:[],toggleOnSelectedRowsChange:n}):Object.assign(Object.assign({},e),{selectedCount:1,allSelected:!1,selectedRows:[o],toggleOnSelectedRowsChange:n}):l?Object.assign(Object.assign({},e),{selectedCount:e.selectedRows.length>0?e.selectedRows.length-1:0,allSelected:!1,selectedRows:td(e.selectedRows,o,r),toggleOnSelectedRowsChange:n}):Object.assign(Object.assign({},e),{selectedCount:e.selectedRows.length+1,allSelected:e.selectedRows.length+1===i,selectedRows:ed(e.selectedRows,o),toggleOnSelectedRowsChange:n})}case"SELECT_MULTIPLE_ROWS":{const{keyField:r,selectedRows:o,totalRows:l,mergeSelections:i}=t;if(i){const a=[...e.selectedRows,...o.filter(s=>!Kt(s,e.selectedRows,r))];return Object.assign(Object.assign({},e),{selectedCount:a.length,allSelected:!1,selectedRows:a,toggleOnSelectedRowsChange:n})}return Object.assign(Object.assign({},e),{selectedCount:o.length,allSelected:o.length===l,selectedRows:o,toggleOnSelectedRowsChange:n})}case"CLEAR_SELECTED_ROWS":{const{selectedRowsFlag:r}=t;return Object.assign(Object.assign({},e),{allSelected:!1,selectedCount:0,selectedRows:[],selectedRowsFlag:r})}case"SORT_CHANGE":{const{sortDirection:r,selectedColumn:o,clearSelectedOnSort:l}=t;return Object.assign(Object.assign(Object.assign({},e),{selectedColumn:o,sortDirection:r,currentPage:1}),l&&{allSelected:!1,selectedCount:0,selectedRows:[],toggleOnSelectedRowsChange:n})}case"CHANGE_PAGE":{const{page:r,paginationServer:o,visibleOnly:l,persistSelectedOnPageChange:i}=t,a=o&&i,s=o&&!i||l;return Object.assign(Object.assign(Object.assign(Object.assign({},e),{currentPage:r}),a&&{allSelected:!1}),s&&{allSelected:!1,selectedCount:0,selectedRows:[],toggleOnSelectedRowsChange:n})}case"CHANGE_ROWS_PER_PAGE":{const{rowsPerPage:r,page:o}=t;return Object.assign(Object.assign({},e),{currentPage:o,rowsPerPage:r})}}}const rd=U`
	pointer-events: none;
	opacity: 0.4;
`,od=H.div`
	position: relative;
	box-sizing: border-box;
	display: flex;
	flex-direction: column;
	width: 100%;
	height: 100%;
	max-width: 100%;
	${({disabled:e})=>e&&rd};
	${({theme:e})=>e.table.style};
`,ld=U`
	position: sticky;
	position: -webkit-sticky; /* Safari */
	top: 0;
	z-index: 1;
`,id=H.div`
	display: flex;
	width: 100%;
	${({$fixedHeader:e})=>e&&ld};
	${({theme:e})=>e.head.style};
`,ad=H.div`
	display: flex;
	align-items: stretch;
	width: 100%;
	${({theme:e})=>e.headRow.style};
	${({$dense:e,theme:t})=>e&&t.headRow.denseStyle};
`,Vl=(e,...t)=>U`
		@media screen and (max-width: ${599}px) {
			${U(e,...t)}
		}
	`,sd=(e,...t)=>U`
		@media screen and (max-width: ${959}px) {
			${U(e,...t)}
		}
	`,cd=(e,...t)=>U`
		@media screen and (max-width: ${1280}px) {
			${U(e,...t)}
		}
	`,ud=e=>(t,...n)=>U`
			@media screen and (max-width: ${e}px) {
				${U(t,...n)}
			}
		`,ht=H.div`
	position: relative;
	display: flex;
	align-items: center;
	box-sizing: border-box;
	line-height: normal;
	${({theme:e,$headCell:t})=>e[t?"headCells":"cells"].style};
	${({$noPadding:e})=>e&&"padding: 0"};
`,ql=H(ht)`
	flex-grow: ${({button:e,grow:t})=>t===0||e?0:t||1};
	flex-shrink: 0;
	flex-basis: 0;
	max-width: ${({maxWidth:e})=>e||"100%"};
	min-width: ${({minWidth:e})=>e||"100px"};
	${({width:e})=>e&&U`
			min-width: ${e};
			max-width: ${e};
		`};
	${({right:e})=>e&&"justify-content: flex-end"};
	${({button:e,center:t})=>(t||e)&&"justify-content: center"};
	${({compact:e,button:t})=>(e||t)&&"padding: 0"};

	/* handle hiding cells */
	${({hide:e})=>e&&e==="sm"&&Vl`
    display: none;
  `};
	${({hide:e})=>e&&e==="md"&&sd`
    display: none;
  `};
	${({hide:e})=>e&&e==="lg"&&cd`
    display: none;
  `};
	${({hide:e})=>e&&Number.isInteger(e)&&ud(e)`
    display: none;
  `};
`,dd=U`
	div:first-child {
		white-space: ${({$wrapCell:e})=>e?"normal":"nowrap"};
		overflow: ${({$allowOverflow:e})=>e?"visible":"hidden"};
		text-overflow: ellipsis;
	}
`,fd=H(ql).attrs(e=>({style:e.style}))`
	${({$renderAsCell:e})=>!e&&dd};
	${({theme:e,$isDragging:t})=>t&&e.cells.draggingStyle};
	${({$cellStyle:e})=>e};
`;var pd=d.memo(function({id:e,column:t,row:n,rowIndex:r,dataTag:o,isDragging:l,onDragStart:i,onDragOver:a,onDragEnd:s,onDragEnter:c,onDragLeave:u}){const{conditionalStyle:f,classNames:p}=Wl(n,t.conditionalCellStyles,["rdt_TableCell"]);return d.createElement(fd,{id:e,"data-column-id":t.id,role:"cell",className:p,"data-tag":o,$cellStyle:t.style,$renderAsCell:!!t.cell,$allowOverflow:t.allowOverflow,button:t.button,center:t.center,compact:t.compact,grow:t.grow,hide:t.hide,maxWidth:t.maxWidth,minWidth:t.minWidth,right:t.right,width:t.width,$wrapCell:t.wrap,style:f,$isDragging:l,onDragStart:i,onDragOver:a,onDragEnd:s,onDragEnter:c,onDragLeave:u},!t.cell&&d.createElement("div",{"data-tag":o},function(h,g,m,w){return g?m&&typeof m=="function"?m(h,w):g(h,w):null}(n,t.selector,t.format,r)),t.cell&&t.cell(n,r,t,e))});const Vo="input";var Gl=d.memo(function({name:e,component:t=Vo,componentOptions:n={style:{}},indeterminate:r=!1,checked:o=!1,disabled:l=!1,onClick:i=ee}){const a=t,s=a!==Vo?n.style:(u=>Object.assign(Object.assign({fontSize:"18px"},!u&&{cursor:"pointer"}),{padding:0,marginTop:"1px",verticalAlign:"middle",position:"relative"}))(l),c=d.useMemo(()=>function(u,...f){let p;return Object.keys(u).map(h=>u[h]).forEach((h,g)=>{typeof h=="function"&&(p=Object.assign(Object.assign({},u),{[Object.keys(u)[g]]:h(...f)}))}),p||u}(n,r),[n,r]);return d.createElement(a,Object.assign({type:"checkbox",ref:u=>{u&&(u.indeterminate=r)},style:s,onClick:l?ee:i,name:e,"aria-label":e,checked:o,disabled:l},c,{onChange:ee}))});const hd=H(ht)`
	flex: 0 0 48px;
	min-width: 48px;
	justify-content: center;
	align-items: center;
	user-select: none;
	white-space: nowrap;
`;function gd({name:e,keyField:t,row:n,rowCount:r,selected:o,selectableRowsComponent:l,selectableRowsComponentProps:i,selectableRowsSingle:a,selectableRowDisabled:s,onSelectedRow:c}){const u=!(!s||!s(n));return d.createElement(hd,{onClick:f=>f.stopPropagation(),className:"rdt_TableCell",$noPadding:!0},d.createElement(Gl,{name:e,component:l,componentOptions:i,checked:o,"aria-checked":o,onClick:()=>{c({type:"SELECT_SINGLE_ROW",row:n,isSelected:o,keyField:t,rowCount:r,singleSelect:a})},disabled:u}))}const md=H.button`
	display: inline-flex;
	align-items: center;
	user-select: none;
	white-space: nowrap;
	border: none;
	background-color: transparent;
	${({theme:e})=>e.expanderButton.style};
`;function yd({disabled:e=!1,expanded:t=!1,expandableIcon:n,id:r,row:o,onToggled:l}){const i=t?n.expanded:n.collapsed;return d.createElement(md,{"aria-disabled":e,onClick:()=>l&&l(o),"data-testid":`expander-button-${r}`,disabled:e,"aria-label":t?"Collapse Row":"Expand Row",role:"button",type:"button"},i)}const bd=H(ht)`
	white-space: nowrap;
	font-weight: 400;
	min-width: 48px;
	${({theme:e})=>e.expanderCell.style};
`;function xd({row:e,expanded:t=!1,expandableIcon:n,id:r,onToggled:o,disabled:l=!1}){return d.createElement(bd,{onClick:i=>i.stopPropagation(),$noPadding:!0},d.createElement(yd,{id:r,row:e,expanded:t,expandableIcon:n,disabled:l,onToggled:o}))}const wd=H.div`
	width: 100%;
	box-sizing: border-box;
	${({theme:e})=>e.expanderRow.style};
	${({$extendedRowStyle:e})=>e};
`;var vd=d.memo(function({data:e,ExpanderComponent:t,expanderComponentProps:n,extendedRowStyle:r,extendedClassNames:o}){const l=["rdt_ExpanderRow",...o.split(" ").filter(i=>i!=="rdt_TableRow")].join(" ");return d.createElement(wd,{className:l,$extendedRowStyle:r},d.createElement(t,Object.assign({data:e},n)))});const Ln="allowRowEvents";var rn,Bn,qo;(function(e){e.LTR="ltr",e.RTL="rtl",e.AUTO="auto"})(rn||(rn={})),function(e){e.LEFT="left",e.RIGHT="right",e.CENTER="center"}(Bn||(Bn={})),function(e){e.SM="sm",e.MD="md",e.LG="lg"}(qo||(qo={}));const kd=U`
	&:hover {
		${({$highlightOnHover:e,theme:t})=>e&&t.rows.highlightOnHoverStyle};
	}
`,Cd=U`
	&:hover {
		cursor: pointer;
	}
`,Ed=H.div.attrs(e=>({style:e.style}))`
	display: flex;
	align-items: stretch;
	align-content: stretch;
	width: 100%;
	box-sizing: border-box;
	${({theme:e})=>e.rows.style};
	${({$dense:e,theme:t})=>e&&t.rows.denseStyle};
	${({$striped:e,theme:t})=>e&&t.rows.stripedStyle};
	${({$highlightOnHover:e})=>e&&kd};
	${({$pointerOnHover:e})=>e&&Cd};
	${({$selected:e,theme:t})=>e&&t.rows.selectedHighlightStyle};
	${({$conditionalStyle:e})=>e};
`;function Sd({columns:e=[],conditionalRowStyles:t=[],defaultExpanded:n=!1,defaultExpanderDisabled:r=!1,dense:o=!1,expandableIcon:l,expandableRows:i=!1,expandableRowsComponent:a,expandableRowsComponentProps:s,expandableRowsHideExpander:c,expandOnRowClicked:u=!1,expandOnRowDoubleClicked:f=!1,highlightOnHover:p=!1,id:h,expandableInheritConditionalStyles:g,keyField:m,onRowClicked:w=ee,onRowDoubleClicked:y=ee,onRowMouseEnter:v=ee,onRowMouseLeave:x=ee,onRowExpandToggled:S=ee,onSelectedRow:I=ee,pointerOnHover:F=!1,row:T,rowCount:$,rowIndex:M,selectableRowDisabled:_=null,selectableRows:P=!1,selectableRowsComponent:N,selectableRowsComponentProps:R,selectableRowsHighlight:O=!1,selectableRowsSingle:Y=!1,selected:re,striped:he=!1,draggingColumnId:ve,onDragStart:je,onDragOver:Ie,onDragEnd:We,onDragEnter:oe,onDragLeave:De}){const[ue,ke]=d.useState(n);d.useEffect(()=>{ke(n)},[n]);const J=d.useCallback(()=>{ke(!ue),S(!ue,T)},[ue,S,T]),Le=F||i&&(u||f),ge=d.useCallback(Q=>{Q.target.getAttribute("data-tag")===Ln&&(w(T,Q),!r&&i&&u&&J())},[r,u,i,J,w,T]),me=d.useCallback(Q=>{Q.target.getAttribute("data-tag")===Ln&&(y(T,Q),!r&&i&&f&&J())},[r,f,i,J,y,T]),Ce=d.useCallback(Q=>{v(T,Q)},[v,T]),de=d.useCallback(Q=>{x(T,Q)},[x,T]),Ae=st(T,m),{conditionalStyle:Ke,classNames:Qe}=Wl(T,t,["rdt_TableRow"]),Ze=O&&re,et=g?Ke:{},tt=he&&M%2==0;return d.createElement(d.Fragment,null,d.createElement(Ed,{id:`row-${h}`,role:"row",$striped:tt,$highlightOnHover:p,$pointerOnHover:!r&&Le,$dense:o,onClick:ge,onDoubleClick:me,onMouseEnter:Ce,onMouseLeave:de,className:Qe,$selected:Ze,$conditionalStyle:Ke},P&&d.createElement(gd,{name:`select-row-${Ae}`,keyField:m,row:T,rowCount:$,selected:re,selectableRowsComponent:N,selectableRowsComponentProps:R,selectableRowDisabled:_,selectableRowsSingle:Y,onSelectedRow:I}),i&&!c&&d.createElement(xd,{id:Ae,expandableIcon:l,expanded:ue,row:T,onToggled:J,disabled:r}),e.map(Q=>Q.omit?null:d.createElement(pd,{id:`cell-${Q.id}-${Ae}`,key:`cell-${Q.id}-${Ae}`,dataTag:Q.ignoreRowClick||Q.button?null:Ln,column:Q,row:T,rowIndex:M,isDragging:Pt(ve,Q.id),onDragStart:je,onDragOver:Ie,onDragEnd:We,onDragEnter:oe,onDragLeave:De}))),i&&ue&&d.createElement(vd,{key:`expander-${Ae}`,data:T,extendedRowStyle:et,extendedClassNames:Qe,ExpanderComponent:a,expanderComponentProps:s}))}const Rd=H.span`
	padding: 2px;
	color: inherit;
	flex-grow: 0;
	flex-shrink: 0;
	${({$sortActive:e})=>e?"opacity: 1":"opacity: 0"};
	${({$sortDirection:e})=>e==="desc"&&"transform: rotate(180deg)"};
`,Pd=({sortActive:e,sortDirection:t})=>V.createElement(Rd,{$sortActive:e,$sortDirection:t},"▲"),Od=H(ql)`
	${({button:e})=>e&&"text-align: center"};
	${({theme:e,$isDragging:t})=>t&&e.headCells.draggingStyle};
`,Td=U`
	cursor: pointer;
	span.__rdt_custom_sort_icon__ {
		i,
		svg {
			transform: 'translate3d(0, 0, 0)';
			${({$sortActive:e})=>e?"opacity: 1":"opacity: 0"};
			color: inherit;
			font-size: 18px;
			height: 18px;
			width: 18px;
			backface-visibility: hidden;
			transform-style: preserve-3d;
			transition-duration: 95ms;
			transition-property: transform;
		}

		&.asc i,
		&.asc svg {
			transform: rotate(180deg);
		}
	}

	${({$sortActive:e})=>!e&&U`
			&:hover,
			&:focus {
				opacity: 0.7;

				span,
				span.__rdt_custom_sort_icon__ * {
					opacity: 0.7;
				}
			}
		`};
`,Id=H.div`
	display: inline-flex;
	align-items: center;
	justify-content: inherit;
	height: 100%;
	width: 100%;
	outline: none;
	user-select: none;
	overflow: hidden;
	${({disabled:e})=>!e&&Td};
`,Dd=H.div`
	overflow: hidden;
	white-space: nowrap;
	text-overflow: ellipsis;
`;var Ld=d.memo(function({column:e,disabled:t,draggingColumnId:n,selectedColumn:r={},sortDirection:o,sortIcon:l,sortServer:i,pagination:a,paginationServer:s,persistSelectedOnSort:c,selectableRowsVisibleOnly:u,onSort:f,onDragStart:p,onDragOver:h,onDragEnd:g,onDragEnter:m,onDragLeave:w}){d.useEffect(()=>{typeof e.selector=="string"&&console.error(`Warning: ${e.selector} is a string based column selector which has been deprecated as of v7 and will be removed in v8. Instead, use a selector function e.g. row => row[field]...`)},[]);const[y,v]=d.useState(!1),x=d.useRef(null);if(d.useEffect(()=>{x.current&&v(x.current.scrollWidth>x.current.clientWidth)},[y]),e.omit)return null;const S=()=>{if(!e.sortable&&!e.selector)return;let R=o;Pt(r.id,e.id)&&(R=o===Ue.ASC?Ue.DESC:Ue.ASC),f({type:"SORT_CHANGE",sortDirection:R,selectedColumn:e,clearSelectedOnSort:a&&s&&!c||i||u})},I=R=>d.createElement(Pd,{sortActive:R,sortDirection:o}),F=()=>d.createElement("span",{className:[o,"__rdt_custom_sort_icon__"].join(" ")},l),T=!(!e.sortable||!Pt(r.id,e.id)),$=!e.sortable||t,M=e.sortable&&!l&&!e.right,_=e.sortable&&!l&&e.right,P=e.sortable&&l&&!e.right,N=e.sortable&&l&&e.right;return d.createElement(Od,{"data-column-id":e.id,className:"rdt_TableCol",$headCell:!0,allowOverflow:e.allowOverflow,button:e.button,compact:e.compact,grow:e.grow,hide:e.hide,maxWidth:e.maxWidth,minWidth:e.minWidth,right:e.right,center:e.center,width:e.width,draggable:e.reorder,$isDragging:Pt(e.id,n),onDragStart:p,onDragOver:h,onDragEnd:g,onDragEnter:m,onDragLeave:w},e.name&&d.createElement(Id,{"data-column-id":e.id,"data-sort-id":e.id,role:"columnheader",tabIndex:0,className:"rdt_TableCol_Sortable",onClick:$?void 0:S,onKeyPress:$?void 0:R=>{R.key==="Enter"&&S()},$sortActive:!$&&T,disabled:$},!$&&N&&F(),!$&&_&&I(T),typeof e.name=="string"?d.createElement(Dd,{title:y?e.name:void 0,ref:x,"data-column-id":e.id},e.name):e.name,!$&&P&&F(),!$&&M&&I(T)))});const Ad=H(ht)`
	flex: 0 0 48px;
	justify-content: center;
	align-items: center;
	user-select: none;
	white-space: nowrap;
	font-size: unset;
`;function $d({headCell:e=!0,rowData:t,keyField:n,allSelected:r,mergeSelections:o,selectedRows:l,selectableRowsComponent:i,selectableRowsComponentProps:a,selectableRowDisabled:s,onSelectAllRows:c}){const u=l.length>0&&!r,f=s?t.filter(g=>!s(g)):t,p=f.length===0,h=Math.min(t.length,f.length);return d.createElement(Ad,{className:"rdt_TableCol",$headCell:e,$noPadding:!0},d.createElement(Gl,{name:"select-all-rows",component:i,componentOptions:a,onClick:()=>{c({type:"SELECT_ALL_ROWS",rows:f,rowCount:h,mergeSelections:o,keyField:n})},checked:r,indeterminate:u,disabled:p}))}function Xl(e=rn.AUTO){const t=typeof window=="object",[n,r]=d.useState(!1);return d.useEffect(()=>{if(t)if(e!=="auto")r(e==="rtl");else{const o=!(!window.document||!window.document.createElement),l=document.getElementsByTagName("BODY")[0],i=document.getElementsByTagName("HTML")[0],a=l.dir==="rtl"||i.dir==="rtl";r(o&&a)}},[e,t]),n}const _d=H.div`
	display: flex;
	align-items: center;
	flex: 1 0 auto;
	height: 100%;
	color: ${({theme:e})=>e.contextMenu.fontColor};
	font-size: ${({theme:e})=>e.contextMenu.fontSize};
	font-weight: 400;
`,jd=H.div`
	display: flex;
	align-items: center;
	justify-content: flex-end;
	flex-wrap: wrap;
`,Go=H.div`
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	box-sizing: inherit;
	z-index: 1;
	align-items: center;
	justify-content: space-between;
	display: flex;
	${({$rtl:e})=>e&&"direction: rtl"};
	${({theme:e})=>e.contextMenu.style};
	${({theme:e,$visible:t})=>t&&e.contextMenu.activeStyle};
`;function Fd({contextMessage:e,contextActions:t,contextComponent:n,selectedCount:r,direction:o}){const l=Xl(o),i=r>0;return n?d.createElement(Go,{$visible:i},d.cloneElement(n,{selectedCount:r})):d.createElement(Go,{$visible:i,$rtl:l},d.createElement(_d,null,((a,s,c)=>{if(s===0)return null;const u=s===1?a.singular:a.plural;return c?`${s} ${a.message||""} ${u}`:`${s} ${u} ${a.message||""}`})(e,r,l)),d.createElement(jd,null,t))}const Md=H.div`
	position: relative;
	box-sizing: border-box;
	overflow: hidden;
	display: flex;
	flex: 1 1 auto;
	align-items: center;
	justify-content: space-between;
	width: 100%;
	flex-wrap: wrap;
	${({theme:e})=>e.header.style}
`,Nd=H.div`
	flex: 1 0 auto;
	color: ${({theme:e})=>e.header.fontColor};
	font-size: ${({theme:e})=>e.header.fontSize};
	font-weight: 400;
`,Hd=H.div`
	flex: 1 0 auto;
	display: flex;
	align-items: center;
	justify-content: flex-end;

	> * {
		margin-left: 5px;
	}
`,zd=({title:e,actions:t=null,contextMessage:n,contextActions:r,contextComponent:o,selectedCount:l,direction:i,showMenu:a=!0})=>d.createElement(Md,{className:"rdt_TableHeader",role:"heading","aria-level":1},d.createElement(Nd,null,e),t&&d.createElement(Hd,null,t),a&&d.createElement(Fd,{contextMessage:n,contextActions:r,contextComponent:o,direction:i,selectedCount:l}));function Yl(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function"){var o=0;for(r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]])}return n}const Bd={left:"flex-start",right:"flex-end",center:"center"},Ud=H.header`
	position: relative;
	display: flex;
	flex: 1 1 auto;
	box-sizing: border-box;
	align-items: center;
	padding: 4px 16px 4px 24px;
	width: 100%;
	justify-content: ${({align:e})=>Bd[e]};
	flex-wrap: ${({$wrapContent:e})=>e?"wrap":"nowrap"};
	${({theme:e})=>e.subHeader.style}
`,Wd=e=>{var{align:t="right",wrapContent:n=!0}=e,r=Yl(e,["align","wrapContent"]);return d.createElement(Ud,Object.assign({align:t,$wrapContent:n},r))},Vd=H.div`
	display: flex;
	flex-direction: column;
`,qd=H.div`
	position: relative;
	width: 100%;
	border-radius: inherit;
	${({$responsive:e,$fixedHeader:t})=>e&&U`
			overflow-x: auto;

			// hidden prevents vertical scrolling in firefox when fixedHeader is disabled
			overflow-y: ${t?"auto":"hidden"};
			min-height: 0;
		`};

	${({$fixedHeader:e=!1,$fixedHeaderScrollHeight:t="100vh"})=>e&&U`
			max-height: ${t};
			-webkit-overflow-scrolling: touch;
		`};

	${({theme:e})=>e.responsiveWrapper.style};
`,Xo=H.div`
	position: relative;
	box-sizing: border-box;
	width: 100%;
	height: 100%;
	${e=>e.theme.progress.style};
`,Gd=H.div`
	position: relative;
	width: 100%;
	${({theme:e})=>e.tableWrapper.style};
`,Xd=H(ht)`
	white-space: nowrap;
	${({theme:e})=>e.expanderCell.style};
`,Yd=H.div`
	box-sizing: border-box;
	width: 100%;
	height: 100%;
	${({theme:e})=>e.noData.style};
`,Jd=()=>V.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24"},V.createElement("path",{d:"M7 10l5 5 5-5z"}),V.createElement("path",{d:"M0 0h24v24H0z",fill:"none"})),Kd=H.select`
	cursor: pointer;
	height: 24px;
	max-width: 100%;
	user-select: none;
	padding-left: 8px;
	padding-right: 24px;
	box-sizing: content-box;
	font-size: inherit;
	color: inherit;
	border: none;
	background-color: transparent;
	appearance: none;
	direction: ltr;
	flex-shrink: 0;

	&::-ms-expand {
		display: none;
	}

	&:disabled::-ms-expand {
		background: #f60;
	}

	option {
		color: initial;
	}
`,Qd=H.div`
	position: relative;
	flex-shrink: 0;
	font-size: inherit;
	color: inherit;
	margin-top: 1px;

	svg {
		top: 0;
		right: 0;
		color: inherit;
		position: absolute;
		fill: currentColor;
		width: 24px;
		height: 24px;
		display: inline-block;
		user-select: none;
		pointer-events: none;
	}
`,Zd=e=>{var{defaultValue:t,onChange:n}=e,r=Yl(e,["defaultValue","onChange"]);return d.createElement(Qd,null,d.createElement(Kd,Object.assign({onChange:n,defaultValue:t},r)),d.createElement(Jd,null))},C={columns:[],data:[],title:"",keyField:"id",selectableRows:!1,selectableRowsHighlight:!1,selectableRowsNoSelectAll:!1,selectableRowSelected:null,selectableRowDisabled:null,selectableRowsComponent:"input",selectableRowsComponentProps:{},selectableRowsVisibleOnly:!1,selectableRowsSingle:!1,clearSelectedRows:!1,expandableRows:!1,expandableRowDisabled:null,expandableRowExpanded:null,expandOnRowClicked:!1,expandableRowsHideExpander:!1,expandOnRowDoubleClicked:!1,expandableInheritConditionalStyles:!1,expandableRowsComponent:function(){return V.createElement("div",null,"To add an expander pass in a component instance via ",V.createElement("strong",null,"expandableRowsComponent"),". You can then access props.data from this component.")},expandableIcon:{collapsed:V.createElement(()=>V.createElement("svg",{fill:"currentColor",height:"24",viewBox:"0 0 24 24",width:"24",xmlns:"http://www.w3.org/2000/svg"},V.createElement("path",{d:"M8.59 16.34l4.58-4.59-4.58-4.59L10 5.75l6 6-6 6z"}),V.createElement("path",{d:"M0-.25h24v24H0z",fill:"none"})),null),expanded:V.createElement(()=>V.createElement("svg",{fill:"currentColor",height:"24",viewBox:"0 0 24 24",width:"24",xmlns:"http://www.w3.org/2000/svg"},V.createElement("path",{d:"M7.41 7.84L12 12.42l4.59-4.58L18 9.25l-6 6-6-6z"}),V.createElement("path",{d:"M0-.75h24v24H0z",fill:"none"})),null)},expandableRowsComponentProps:{},progressPending:!1,progressComponent:V.createElement("div",{style:{fontSize:"24px",fontWeight:700,padding:"24px"}},"Loading..."),persistTableHead:!1,sortIcon:null,sortFunction:null,sortServer:!1,striped:!1,highlightOnHover:!1,pointerOnHover:!1,noContextMenu:!1,contextMessage:{singular:"item",plural:"items",message:"selected"},actions:null,contextActions:null,contextComponent:null,defaultSortFieldId:null,defaultSortAsc:!0,responsive:!0,noDataComponent:V.createElement("div",{style:{padding:"24px"}},"There are no records to display"),disabled:!1,noTableHead:!1,noHeader:!1,subHeader:!1,subHeaderAlign:Bn.RIGHT,subHeaderWrap:!0,subHeaderComponent:null,fixedHeader:!1,fixedHeaderScrollHeight:"100vh",pagination:!1,paginationServer:!1,paginationServerOptions:{persistSelectedOnSort:!1,persistSelectedOnPageChange:!1},paginationDefaultPage:1,paginationResetDefaultPage:!1,paginationTotalRows:0,paginationPerPage:10,paginationRowsPerPageOptions:[10,15,20,25,30],paginationComponent:null,paginationComponentOptions:{},paginationIconFirstPage:V.createElement(()=>V.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24","aria-hidden":"true",role:"presentation"},V.createElement("path",{d:"M18.41 16.59L13.82 12l4.59-4.59L17 6l-6 6 6 6zM6 6h2v12H6z"}),V.createElement("path",{fill:"none",d:"M24 24H0V0h24v24z"})),null),paginationIconLastPage:V.createElement(()=>V.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24","aria-hidden":"true",role:"presentation"},V.createElement("path",{d:"M5.59 7.41L10.18 12l-4.59 4.59L7 18l6-6-6-6zM16 6h2v12h-2z"}),V.createElement("path",{fill:"none",d:"M0 0h24v24H0V0z"})),null),paginationIconNext:V.createElement(()=>V.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24","aria-hidden":"true",role:"presentation"},V.createElement("path",{d:"M10 6L8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z"}),V.createElement("path",{d:"M0 0h24v24H0z",fill:"none"})),null),paginationIconPrevious:V.createElement(()=>V.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24","aria-hidden":"true",role:"presentation"},V.createElement("path",{d:"M15.41 7.41L14 6l-6 6 6 6 1.41-1.41L10.83 12z"}),V.createElement("path",{d:"M0 0h24v24H0z",fill:"none"})),null),dense:!1,conditionalRowStyles:[],theme:"default",customStyles:{},direction:rn.AUTO,onChangePage:ee,onChangeRowsPerPage:ee,onRowClicked:ee,onRowDoubleClicked:ee,onRowMouseEnter:ee,onRowMouseLeave:ee,onRowExpandToggled:ee,onSelectedRowsChange:ee,onSort:ee,onColumnOrderChange:ee},ef={rowsPerPageText:"Rows per page:",rangeSeparatorText:"of",noRowsPerPage:!1,selectAllRowsItem:!1,selectAllRowsItemText:"All"},tf=H.nav`
	display: flex;
	flex: 1 1 auto;
	justify-content: flex-end;
	align-items: center;
	box-sizing: border-box;
	padding-right: 8px;
	padding-left: 8px;
	width: 100%;
	${({theme:e})=>e.pagination.style};
`,Xt=H.button`
	position: relative;
	display: block;
	user-select: none;
	border: none;
	${({theme:e})=>e.pagination.pageButtonsStyle};
	${({$isRTL:e})=>e&&"transform: scale(-1, -1)"};
`,nf=H.div`
	display: flex;
	align-items: center;
	border-radius: 4px;
	white-space: nowrap;
	${Vl`
    width: 100%;
    justify-content: space-around;
  `};
`,Jl=H.span`
	flex-shrink: 1;
	user-select: none;
`,rf=H(Jl)`
	margin: 0 24px;
`,of=H(Jl)`
	margin: 0 4px;
`;var lf=d.memo(function({rowsPerPage:e,rowCount:t,currentPage:n,direction:r=C.direction,paginationRowsPerPageOptions:o=C.paginationRowsPerPageOptions,paginationIconLastPage:l=C.paginationIconLastPage,paginationIconFirstPage:i=C.paginationIconFirstPage,paginationIconNext:a=C.paginationIconNext,paginationIconPrevious:s=C.paginationIconPrevious,paginationComponentOptions:c=C.paginationComponentOptions,onChangeRowsPerPage:u=C.onChangeRowsPerPage,onChangePage:f=C.onChangePage}){const p=(()=>{const R=typeof window=="object";function O(){return{width:R?window.innerWidth:void 0,height:R?window.innerHeight:void 0}}const[Y,re]=d.useState(O);return d.useEffect(()=>{if(!R)return()=>null;function he(){re(O())}return window.addEventListener("resize",he),()=>window.removeEventListener("resize",he)},[]),Y})(),h=Xl(r),g=p.width&&p.width>599,m=Rt(t,e),w=n*e,y=w-e+1,v=n===1,x=n===m,S=Object.assign(Object.assign({},ef),c),I=n===m?`${y}-${t} ${S.rangeSeparatorText} ${t}`:`${y}-${w} ${S.rangeSeparatorText} ${t}`,F=d.useCallback(()=>f(n-1),[n,f]),T=d.useCallback(()=>f(n+1),[n,f]),$=d.useCallback(()=>f(1),[f]),M=d.useCallback(()=>f(Rt(t,e)),[f,t,e]),_=d.useCallback(R=>u(Number(R.target.value),n),[n,u]),P=o.map(R=>d.createElement("option",{key:R,value:R},R));S.selectAllRowsItem&&P.push(d.createElement("option",{key:-1,value:t},S.selectAllRowsItemText));const N=d.createElement(Zd,{onChange:_,defaultValue:e,"aria-label":S.rowsPerPageText},P);return d.createElement(tf,{className:"rdt_Pagination"},!S.noRowsPerPage&&g&&d.createElement(d.Fragment,null,d.createElement(of,null,S.rowsPerPageText),N),g&&d.createElement(rf,null,I),d.createElement(nf,null,d.createElement(Xt,{id:"pagination-first-page",type:"button","aria-label":"First Page","aria-disabled":v,onClick:$,disabled:v,$isRTL:h},i),d.createElement(Xt,{id:"pagination-previous-page",type:"button","aria-label":"Previous Page","aria-disabled":v,onClick:F,disabled:v,$isRTL:h},s),!S.noRowsPerPage&&!g&&N,d.createElement(Xt,{id:"pagination-next-page",type:"button","aria-label":"Next Page","aria-disabled":x,onClick:T,disabled:x,$isRTL:h},a),d.createElement(Xt,{id:"pagination-last-page",type:"button","aria-label":"Last Page","aria-disabled":x,onClick:M,disabled:x,$isRTL:h},l)))});const Xe=(e,t)=>{const n=d.useRef(!0);d.useEffect(()=>{n.current?n.current=!1:e()},t)};function af(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var sf=function(e){return function(t){return!!t&&typeof t=="object"}(e)&&!function(t){var n=Object.prototype.toString.call(t);return n==="[object RegExp]"||n==="[object Date]"||function(r){return r.$$typeof===cf}(t)}(e)},cf=typeof Symbol=="function"&&Symbol.for?Symbol.for("react.element"):60103;function It(e,t){return t.clone!==!1&&t.isMergeableObject(e)?ct((n=e,Array.isArray(n)?[]:{}),e,t):e;var n}function uf(e,t,n){return e.concat(t).map(function(r){return It(r,n)})}function Yo(e){return Object.keys(e).concat(function(t){return Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(t).filter(function(n){return Object.propertyIsEnumerable.call(t,n)}):[]}(e))}function Jo(e,t){try{return t in e}catch{return!1}}function df(e,t,n){var r={};return n.isMergeableObject(e)&&Yo(e).forEach(function(o){r[o]=It(e[o],n)}),Yo(t).forEach(function(o){(function(l,i){return Jo(l,i)&&!(Object.hasOwnProperty.call(l,i)&&Object.propertyIsEnumerable.call(l,i))})(e,o)||(Jo(e,o)&&n.isMergeableObject(t[o])?r[o]=function(l,i){if(!i.customMerge)return ct;var a=i.customMerge(l);return typeof a=="function"?a:ct}(o,n)(e[o],t[o],n):r[o]=It(t[o],n))}),r}function ct(e,t,n){(n=n||{}).arrayMerge=n.arrayMerge||uf,n.isMergeableObject=n.isMergeableObject||sf,n.cloneUnlessOtherwiseSpecified=It;var r=Array.isArray(t);return r===Array.isArray(e)?r?n.arrayMerge(e,t,n):df(e,t,n):It(t,n)}ct.all=function(e,t){if(!Array.isArray(e))throw new Error("first argument should be an array");return e.reduce(function(n,r){return ct(n,r,t)},{})};var Un=af(ct);const Ko={text:{primary:"rgba(0, 0, 0, 0.87)",secondary:"rgba(0, 0, 0, 0.54)",disabled:"rgba(0, 0, 0, 0.38)"},background:{default:"#FFFFFF"},context:{background:"#e3f2fd",text:"rgba(0, 0, 0, 0.87)"},divider:{default:"rgba(0,0,0,.12)"},button:{default:"rgba(0,0,0,.54)",focus:"rgba(0,0,0,.12)",hover:"rgba(0,0,0,.12)",disabled:"rgba(0, 0, 0, .18)"},selected:{default:"#e3f2fd",text:"rgba(0, 0, 0, 0.87)"},highlightOnHover:{default:"#EEEEEE",text:"rgba(0, 0, 0, 0.87)"},striped:{default:"#FAFAFA",text:"rgba(0, 0, 0, 0.87)"}},Be={default:Ko,light:Ko,dark:{text:{primary:"#FFFFFF",secondary:"rgba(255, 255, 255, 0.7)",disabled:"rgba(0,0,0,.12)"},background:{default:"#424242"},context:{background:"#E91E63",text:"#FFFFFF"},divider:{default:"rgba(81, 81, 81, 1)"},button:{default:"#FFFFFF",focus:"rgba(255, 255, 255, .54)",hover:"rgba(255, 255, 255, .12)",disabled:"rgba(255, 255, 255, .18)"},selected:{default:"rgba(0, 0, 0, .7)",text:"#FFFFFF"},highlightOnHover:{default:"rgba(0, 0, 0, .7)",text:"#FFFFFF"},striped:{default:"rgba(0, 0, 0, .87)",text:"#FFFFFF"}}};function vf(e="default",t,n="default"){return Be[e]||(Be[e]=Un(Be[n],t||{})),Be[e]=Un(Be[e],t||{}),Be[e]}function ff(e,t,n,r){const[o,l]=d.useState(()=>Wo(e)),[i,a]=d.useState(""),s=d.useRef("");Xe(()=>{l(Wo(e))},[e]);const c=d.useCallback(w=>{var y,v,x;const{attributes:S}=w.target,I=(y=S.getNamedItem("data-column-id"))===null||y===void 0?void 0:y.value;I&&(s.current=((x=(v=o[Gt(o,I)])===null||v===void 0?void 0:v.id)===null||x===void 0?void 0:x.toString())||"",a(s.current))},[o]),u=d.useCallback(w=>{var y;const{attributes:v}=w.target,x=(y=v.getNamedItem("data-column-id"))===null||y===void 0?void 0:y.value;if(x&&s.current&&x!==s.current){const S=Gt(o,s.current),I=Gt(o,x),F=[...o];F[S]=o[I],F[I]=o[S],l(F),t(F)}},[t,o]),f=d.useCallback(w=>{w.preventDefault()},[]),p=d.useCallback(w=>{w.preventDefault()},[]),h=d.useCallback(w=>{w.preventDefault(),s.current="",a("")},[]),g=function(w=!1){return w?Ue.ASC:Ue.DESC}(r),m=d.useMemo(()=>o[Gt(o,n==null?void 0:n.toString())]||{},[n,o]);return{tableColumns:o,draggingColumnId:i,handleDragStart:c,handleDragEnter:u,handleDragOver:f,handleDragLeave:p,handleDragEnd:h,defaultSortDirection:g,defaultSortColumn:m}}var kf=d.memo(function(e){const{data:t=C.data,columns:n=C.columns,title:r=C.title,actions:o=C.actions,keyField:l=C.keyField,striped:i=C.striped,highlightOnHover:a=C.highlightOnHover,pointerOnHover:s=C.pointerOnHover,dense:c=C.dense,selectableRows:u=C.selectableRows,selectableRowsSingle:f=C.selectableRowsSingle,selectableRowsHighlight:p=C.selectableRowsHighlight,selectableRowsNoSelectAll:h=C.selectableRowsNoSelectAll,selectableRowsVisibleOnly:g=C.selectableRowsVisibleOnly,selectableRowSelected:m=C.selectableRowSelected,selectableRowDisabled:w=C.selectableRowDisabled,selectableRowsComponent:y=C.selectableRowsComponent,selectableRowsComponentProps:v=C.selectableRowsComponentProps,onRowExpandToggled:x=C.onRowExpandToggled,onSelectedRowsChange:S=C.onSelectedRowsChange,expandableIcon:I=C.expandableIcon,onChangeRowsPerPage:F=C.onChangeRowsPerPage,onChangePage:T=C.onChangePage,paginationServer:$=C.paginationServer,paginationServerOptions:M=C.paginationServerOptions,paginationTotalRows:_=C.paginationTotalRows,paginationDefaultPage:P=C.paginationDefaultPage,paginationResetDefaultPage:N=C.paginationResetDefaultPage,paginationPerPage:R=C.paginationPerPage,paginationRowsPerPageOptions:O=C.paginationRowsPerPageOptions,paginationIconLastPage:Y=C.paginationIconLastPage,paginationIconFirstPage:re=C.paginationIconFirstPage,paginationIconNext:he=C.paginationIconNext,paginationIconPrevious:ve=C.paginationIconPrevious,paginationComponent:je=C.paginationComponent,paginationComponentOptions:Ie=C.paginationComponentOptions,responsive:We=C.responsive,progressPending:oe=C.progressPending,progressComponent:De=C.progressComponent,persistTableHead:ue=C.persistTableHead,noDataComponent:ke=C.noDataComponent,disabled:J=C.disabled,noTableHead:Le=C.noTableHead,noHeader:ge=C.noHeader,fixedHeader:me=C.fixedHeader,fixedHeaderScrollHeight:Ce=C.fixedHeaderScrollHeight,pagination:de=C.pagination,subHeader:Ae=C.subHeader,subHeaderAlign:Ke=C.subHeaderAlign,subHeaderWrap:Qe=C.subHeaderWrap,subHeaderComponent:Ze=C.subHeaderComponent,noContextMenu:et=C.noContextMenu,contextMessage:tt=C.contextMessage,contextActions:Q=C.contextActions,contextComponent:jt=C.contextComponent,expandableRows:Ve=C.expandableRows,onRowClicked:Ft=C.onRowClicked,onRowDoubleClicked:Mt=C.onRowDoubleClicked,onRowMouseEnter:Nt=C.onRowMouseEnter,onRowMouseLeave:Ht=C.onRowMouseLeave,sortIcon:cn=C.sortIcon,onSort:b=C.onSort,sortFunction:E=C.sortFunction,sortServer:D=C.sortServer,expandableRowsComponent:B=C.expandableRowsComponent,expandableRowsComponentProps:G=C.expandableRowsComponentProps,expandableRowDisabled:ae=C.expandableRowDisabled,expandableRowsHideExpander:Ee=C.expandableRowsHideExpander,expandOnRowClicked:ye=C.expandOnRowClicked,expandOnRowDoubleClicked:qe=C.expandOnRowDoubleClicked,expandableRowExpanded:Fe=C.expandableRowExpanded,expandableInheritConditionalStyles:le=C.expandableInheritConditionalStyles,defaultSortFieldId:Me=C.defaultSortFieldId,defaultSortAsc:be=C.defaultSortAsc,clearSelectedRows:sr=C.clearSelectedRows,conditionalRowStyles:Kl=C.conditionalRowStyles,theme:cr=C.theme,customStyles:ur=C.customStyles,direction:gt=C.direction,onColumnOrderChange:Ql=C.onColumnOrderChange,className:Zl,ariaLabel:dr}=e,{tableColumns:fr,draggingColumnId:pr,handleDragStart:hr,handleDragEnter:gr,handleDragOver:mr,handleDragLeave:yr,handleDragEnd:br,defaultSortDirection:ei,defaultSortColumn:ti}=ff(n,Ql,Me,be),[{rowsPerPage:Ne,currentPage:xe,selectedRows:un,allSelected:xr,selectedCount:wr,selectedColumn:Se,sortDirection:nt,toggleOnSelectedRowsChange:ni},Ge]=d.useReducer(nd,{allSelected:!1,selectedCount:0,selectedRows:[],selectedColumn:ti,toggleOnSelectedRowsChange:!1,sortDirection:ei,currentPage:P,rowsPerPage:R,selectedRowsFlag:!1,contextMessage:C.contextMessage}),{persistSelectedOnSort:vr=!1,persistSelectedOnPageChange:zt=!1}=M,kr=!(!$||!zt&&!vr),ri=de&&!oe&&t.length>0,oi=je||lf,li=d.useMemo(()=>((L={},q="default",ie="default")=>{const we=Be[q]?q:ie;return Un({table:{style:{color:(A=Be[we]).text.primary,backgroundColor:A.background.default}},tableWrapper:{style:{display:"table"}},responsiveWrapper:{style:{}},header:{style:{fontSize:"22px",color:A.text.primary,backgroundColor:A.background.default,minHeight:"56px",paddingLeft:"16px",paddingRight:"8px"}},subHeader:{style:{backgroundColor:A.background.default,minHeight:"52px"}},head:{style:{color:A.text.primary,fontSize:"12px",fontWeight:500}},headRow:{style:{backgroundColor:A.background.default,minHeight:"52px",borderBottomWidth:"1px",borderBottomColor:A.divider.default,borderBottomStyle:"solid"},denseStyle:{minHeight:"32px"}},headCells:{style:{paddingLeft:"16px",paddingRight:"16px"},draggingStyle:{cursor:"move"}},contextMenu:{style:{backgroundColor:A.context.background,fontSize:"18px",fontWeight:400,color:A.context.text,paddingLeft:"16px",paddingRight:"8px",transform:"translate3d(0, -100%, 0)",transitionDuration:"125ms",transitionTimingFunction:"cubic-bezier(0, 0, 0.2, 1)",willChange:"transform"},activeStyle:{transform:"translate3d(0, 0, 0)"}},cells:{style:{paddingLeft:"16px",paddingRight:"16px",wordBreak:"break-word"},draggingStyle:{}},rows:{style:{fontSize:"13px",fontWeight:400,color:A.text.primary,backgroundColor:A.background.default,minHeight:"48px","&:not(:last-of-type)":{borderBottomStyle:"solid",borderBottomWidth:"1px",borderBottomColor:A.divider.default}},denseStyle:{minHeight:"32px"},selectedHighlightStyle:{"&:nth-of-type(n)":{color:A.selected.text,backgroundColor:A.selected.default,borderBottomColor:A.background.default}},highlightOnHoverStyle:{color:A.highlightOnHover.text,backgroundColor:A.highlightOnHover.default,transitionDuration:"0.15s",transitionProperty:"background-color",borderBottomColor:A.background.default,outlineStyle:"solid",outlineWidth:"1px",outlineColor:A.background.default},stripedStyle:{color:A.striped.text,backgroundColor:A.striped.default}},expanderRow:{style:{color:A.text.primary,backgroundColor:A.background.default}},expanderCell:{style:{flex:"0 0 48px"}},expanderButton:{style:{color:A.button.default,fill:A.button.default,backgroundColor:"transparent",borderRadius:"2px",transition:"0.25s",height:"100%",width:"100%","&:hover:enabled":{cursor:"pointer"},"&:disabled":{color:A.button.disabled},"&:hover:not(:disabled)":{cursor:"pointer",backgroundColor:A.button.hover},"&:focus":{outline:"none",backgroundColor:A.button.focus},svg:{margin:"auto"}}},pagination:{style:{color:A.text.secondary,fontSize:"13px",minHeight:"56px",backgroundColor:A.background.default,borderTopStyle:"solid",borderTopWidth:"1px",borderTopColor:A.divider.default},pageButtonsStyle:{borderRadius:"50%",height:"40px",width:"40px",padding:"8px",margin:"px",cursor:"pointer",transition:"0.4s",color:A.button.default,fill:A.button.default,backgroundColor:"transparent","&:disabled":{cursor:"unset",color:A.button.disabled,fill:A.button.disabled},"&:hover:not(:disabled)":{backgroundColor:A.button.hover},"&:focus":{outline:"none",backgroundColor:A.button.focus}}},noData:{style:{display:"flex",alignItems:"center",justifyContent:"center",color:A.text.primary,backgroundColor:A.background.default}},progress:{style:{display:"flex",alignItems:"center",justifyContent:"center",color:A.text.primary,backgroundColor:A.background.default}}},L);var A})(ur,cr),[ur,cr]),ii=d.useMemo(()=>Object.assign({},gt!=="auto"&&{dir:gt}),[gt]),te=d.useMemo(()=>{if(D)return t;if(Se!=null&&Se.sortFunction&&typeof Se.sortFunction=="function"){const L=Se.sortFunction,q=nt===Ue.ASC?L:(ie,we)=>-1*L(ie,we);return[...t].sort(q)}return function(L,q,ie,we){return q?we&&typeof we=="function"?we(L.slice(0),q,ie):L.slice(0).sort((A,dn)=>{const ot=q(A),He=q(dn);if(ie==="asc"){if(ot<He)return-1;if(ot>He)return 1}if(ie==="desc"){if(ot>He)return-1;if(ot<He)return 1}return 0}):L}(t,Se==null?void 0:Se.selector,nt,E)},[D,Se,nt,t,E]),mt=d.useMemo(()=>{if(de&&!$){const L=xe*Ne,q=L-Ne;return te.slice(q,L)}return te},[xe,de,$,Ne,te]),ai=d.useCallback(L=>{Ge(L)},[]),si=d.useCallback(L=>{Ge(L)},[]),ci=d.useCallback(L=>{Ge(L)},[]),ui=d.useCallback((L,q)=>Ft(L,q),[Ft]),di=d.useCallback((L,q)=>Mt(L,q),[Mt]),fi=d.useCallback((L,q)=>Nt(L,q),[Nt]),pi=d.useCallback((L,q)=>Ht(L,q),[Ht]),rt=d.useCallback(L=>Ge({type:"CHANGE_PAGE",page:L,paginationServer:$,visibleOnly:g,persistSelectedOnPageChange:zt}),[$,zt,g]),hi=d.useCallback(L=>{const q=Rt(_||mt.length,L),ie=Dn(xe,q);$||rt(ie),Ge({type:"CHANGE_ROWS_PER_PAGE",page:ie,rowsPerPage:L})},[xe,rt,$,_,mt.length]);if(de&&!$&&te.length>0&&mt.length===0){const L=Rt(te.length,Ne),q=Dn(xe,L);rt(q)}Xe(()=>{S({allSelected:xr,selectedCount:wr,selectedRows:un.slice(0)})},[ni]),Xe(()=>{b(Se,nt,te.slice(0))},[Se,nt]),Xe(()=>{T(xe,_||te.length)},[xe]),Xe(()=>{F(Ne,xe)},[Ne]),Xe(()=>{rt(P)},[P,N]),Xe(()=>{if(de&&$&&_>0){const L=Rt(_,Ne),q=Dn(xe,L);xe!==q&&rt(q)}},[_]),d.useEffect(()=>{Ge({type:"CLEAR_SELECTED_ROWS",selectedRowsFlag:sr})},[f,sr]),d.useEffect(()=>{if(!m)return;const L=te.filter(ie=>m(ie)),q=f?L.slice(0,1):L;Ge({type:"SELECT_MULTIPLE_ROWS",keyField:l,selectedRows:q,totalRows:te.length,mergeSelections:kr})},[t,m]);const gi=g?mt:te,mi=zt||f||h;return d.createElement(Mi,{theme:li},!ge&&(!!r||!!o)&&d.createElement(zd,{title:r,actions:o,showMenu:!et,selectedCount:wr,direction:gt,contextActions:Q,contextComponent:jt,contextMessage:tt}),Ae&&d.createElement(Wd,{align:Ke,wrapContent:Qe},Ze),d.createElement(qd,Object.assign({$responsive:We,$fixedHeader:me,$fixedHeaderScrollHeight:Ce,className:Zl},ii),d.createElement(Gd,null,oe&&!ue&&d.createElement(Xo,null,De),d.createElement(od,Object.assign({disabled:J,className:"rdt_Table",role:"table"},dr&&{"aria-label":dr}),!Le&&(!!ue||te.length>0&&!oe)&&d.createElement(id,{className:"rdt_TableHead",role:"rowgroup",$fixedHeader:me},d.createElement(ad,{className:"rdt_TableHeadRow",role:"row",$dense:c},u&&(mi?d.createElement(ht,{style:{flex:"0 0 48px"}}):d.createElement($d,{allSelected:xr,selectedRows:un,selectableRowsComponent:y,selectableRowsComponentProps:v,selectableRowDisabled:w,rowData:gi,keyField:l,mergeSelections:kr,onSelectAllRows:si})),Ve&&!Ee&&d.createElement(Xd,null),fr.map(L=>d.createElement(Ld,{key:L.id,column:L,selectedColumn:Se,disabled:oe||te.length===0,pagination:de,paginationServer:$,persistSelectedOnSort:vr,selectableRowsVisibleOnly:g,sortDirection:nt,sortIcon:cn,sortServer:D,onSort:ai,onDragStart:hr,onDragOver:mr,onDragEnd:br,onDragEnter:gr,onDragLeave:yr,draggingColumnId:pr})))),!te.length&&!oe&&d.createElement(Yd,null,ke),oe&&ue&&d.createElement(Xo,null,De),!oe&&te.length>0&&d.createElement(Vd,{className:"rdt_TableBody",role:"rowgroup"},mt.map((L,q)=>{const ie=st(L,l),we=function(He=""){return typeof He!="number"&&(!He||He.length===0)}(ie)?q:ie,A=Kt(L,un,l),dn=!!(Ve&&Fe&&Fe(L)),ot=!!(Ve&&ae&&ae(L));return d.createElement(Sd,{id:we,key:we,keyField:l,"data-row-id":we,columns:fr,row:L,rowCount:te.length,rowIndex:q,selectableRows:u,expandableRows:Ve,expandableIcon:I,highlightOnHover:a,pointerOnHover:s,dense:c,expandOnRowClicked:ye,expandOnRowDoubleClicked:qe,expandableRowsComponent:B,expandableRowsComponentProps:G,expandableRowsHideExpander:Ee,defaultExpanderDisabled:ot,defaultExpanded:dn,expandableInheritConditionalStyles:le,conditionalRowStyles:Kl,selected:A,selectableRowsHighlight:p,selectableRowsComponent:y,selectableRowsComponentProps:v,selectableRowDisabled:w,selectableRowsSingle:f,striped:i,onRowExpandToggled:x,onRowClicked:ui,onRowDoubleClicked:di,onRowMouseEnter:fi,onRowMouseLeave:pi,onSelectedRow:ci,draggingColumnId:pr,onDragStart:hr,onDragOver:mr,onDragEnd:br,onDragEnter:gr,onDragLeave:yr})}))))),ri&&d.createElement("div",null,d.createElement(oi,{onChangePage:rt,onChangeRowsPerPage:hi,rowCount:_||te.length,currentPage:xe,rowsPerPage:Ne,direction:gt,paginationRowsPerPageOptions:O,paginationIconLastPage:Y,paginationIconFirstPage:re,paginationIconNext:he,paginationIconPrevious:ve,paginationComponentOptions:Ie})))});export{mf as B,wf as C,vf as J,yl as L,yf as M,es as N,xf as R,kf as X,Ye as a,ga as b,gf as c,Ia as d,bf as e,yn as j,hf as u};
//# sourceMappingURL=@react-libs-PgwxcVIh.js.map
